# Search query for SDG 12 - Responsible Consumption and Production, Bergen topic-approach.
Ensure sustainable consumption and production patterns

**Contents**

1. Full query
2. General notes about method for SDG 12
3. Documentation and string sections for each target
4. Contributions
5. Footnotes

## 1. Full query

Results of the full search in its current state can be viewed on Web of Science by clicking here (no filters; publication year = last 5 years): https://www.webofscience.com/wos/woscc/summary/54c23e56-d4a2-4e57-b536-eb1694050d5b-b789b92c/relevance/1

## 2. General notes

This document contains search strings for finding publications related to the **topics** in SDG 12 targets and indicators ("topic approach"; focus on recall, larger result set). We also have a version which finds publications related to the actions in SDG 12 targets and indicators ("action approach"; focus on precision, smaller result set), provided in the same repository as this file. For more explanation, see the Readme in this repository.

The definition of sustainable consumption and production according to the UNEP publication *ABC of SCP* (<a id="ABC">[UNEP, 2010](#f1)</a>) is:
> *The use of services and related products, which respond to basic needs and bring a better quality of life while minimising the use of natural resources and toxic
> materials as well as the emissions of waste and pollutants over the life cycle of the service or product so as not to jeopardise the needs of future generations*

In these phrases SDG 12 is interpreted to be about tools and policies for sustainable production and consumption, about sustainable management and efficient use of natural resources, and about reducing food waste and waste in general as well as managing the life cycle of all wastes (chemical waste in particular) thus reducing pollution and harmful releases to humans and the environment. SDG 12 is about implementing e.g. circular economy approaches, reusing and recycling materials and resources, sustainable public procurements, sustainable practises and reporting on company level and sustainability programs on national and regional level. It also addresses the globally uneven distribution of sustainable consumption and production patterns (with special attention on the developing countries), consumer awareness and monitoring methods for the impacts of sustainable development as well as removing incentives which encourage wasteful consumption. 

Sustainable consumption and production is about *promoting social and economic development within the carrying capacity of ecosystems by delinking economic growth and environmental degradation* (<a id="ABC">[UNEP, 2010](#f1)</a>). Thus, advancing social equity and reducing poverty are essential goals of sustainable consumption and production, as well as addressing climate and other ecological challenges . However, these terms are usually not included in our search queries, since we have focused the queries on the **means to achieve these goals**. Still, in many of the phrases terms `environmental*` `eco` and `green` are used as a variation of `sustainable` to broaden the scope towards e.g. environmentally friendly production, eco-friendly products or green consumption.

We were not quite sure about whether to interpret research about economically sustainable businesses or about Corporate social responsibility (CSR) as relevant to SDG 12 or not. But excluding them would in any case be challenging if not impossible, without losing many relevant results.  

Term `responsible` was initially included as a synonym/variant of sustainable. Even though also relevant articles were found by `responsib*` we decided to remove it from the *Sustainability string*: ("sustainab*" OR "environmental*" OR "ecological*" OR "eco" OR "green") in most of the targets (12.1, 12.6, 12.8 and 12.a) due to too many irrelevant results. Instead, we combine `responsible` with `tourism` and `consumption` since these combinations tend to bring quite a few relevant results. Still, even these combinations bring some noise (e.g. about responsible alcohol consumption). 

For general definition of Sustainable consumption and production we used:
* UN DESA paper *2018 HLPL Review of SDGs implementation* (<a id="HLPF2018">[UNDESA, 2018](#f7)</a>) 
* UN DESA publication *The 10 Year Framework of Programmes on Sustainable Consumption and Production Patterns (10YFP)* (<a id="UNDESA2014">[UN DESA, 2014](#f2)</a>)
* UNEP publication *ABC of SCP* (<a id="ABC">[UNEP, 2010](#f1)</a>)
* *One Planet Network* web pages (<a id="UNone">[UN One Planet Network](#f8)</a>).

Targets and Indicators were found from the UN Statistics Division (UN Statistics Division, 2021). This list includes "the global indicator framework as contained in A/RES/71/313, the refinements agreed by the Statistical Commission at its 49th session in March 2018 (E/CN.3/2018/2, Annex II) and 50th session in March 2019 (E/CN.3/2019/2, Annex II), changes from the 2020 Comprehensive Review (E/CN.3/2020/2, Annex II) and refinements (E/CN.3/2020/2, Annex III) from the 51st session in March 2020, and refinements from the 52nd session in March 2021 (E/CN.3/2021/2, Annex)". (https://unstats.un.org/sdgs/indicators/indicators-list/)

Abbreviations used:
* SCP - Sustainable Consumption and Production
* 10YFP - 10-Year Framework of Programmes on Sustainable Consumption and Production Patterns
* UN - United Nations
* UNEP - United Nations Environment Programme
* UNWTO - World Tourism Organization
* DESA - Department of Economic and Social Affairs
* FAO - The Food and Agriculture Organization of the United Nations
* HLPF - High Level Political Forum


## 3. Targets

### Target 12.1

> **12.1 Implement the 10‑Year Framework of Programmes on Sustainable Consumption and Production Patterns, all countries taking action, with developed countries taking the lead, taking into account the development and capabilities of developing countries**
> 
> 12.1.1 Number of countries developing, adopting or implementing policy instruments aimed at supporting the shift to sustainable consumption and production

This target is interpreted to cover research about programmes and policies to advance sustainable consumption and production, according to the UN's 10-Year Framework of Programmes (10YFP). We interpret this target to be about all countries taking action, and have not included a phrase for supporting the development or capabilities of developing countries here. Target 12.a is specifically about this.

This phrase aims to find research about programmes and policies on sustainable consumption and production. 

The specific programme areas `consumer information` `sustainable lifestyles and education` `sustainable public procurement` `sustainable buildings and construction` `sustainable tourism` `sustainable food systems` and the definitions of them are from the UN DESA publication *The 10 Year Framework of Programmes on Sustainable Consumption and Production Patterns (10YFP)* (<a id="UNDESA2014">[UN DESA, 2014](#f2)</a>). The concepts `resource efficiency` and `product lifecycle` are also mentioned int the 10YFP. Some concepts, even though not mentioned in the 10YFP, are included from the UNEP publication *ABC to SCP*, subtitled *Towards a 10-Year Framework of Programmes on Sustainable Consumption and Production* (<a id="ABC">[UNEP, 2010](#f1)</a>): `waste management` `cleaner production` `sustainable transport` `eco-labelling and certification` `sustainable marketing` `design for sustainability` `ecodesign` `environmentally sound technologies`.

Terms used for policy instruments are paralelled with programmes and were found e.g. from the indicator 12.1.1 metadata (<a id="UNstats2021">[UN Statistics division, 2021](#f2)</a>) https://unstats.un.org/sdgs/metadata/files/Metadata-12-01-01.pdf. 

Some of the terms used in this phrase are central to the focus of this target, but also so generally used that they bring results about research which is not relevant to the targets of SDG 12. For example `resource efficiency` is used in computing sciences, human resources management and when discussing health and social services. `Reuse of resources` can refer to e.g. reuse of data resources and `sustainable housing` can also be about e.g. affordable housing. Also term `green` even when combined the specific terms of the phrase brings results which mention green e.g. as a colour or a name of a person.    

The elements of the phrase are *programmes/policies + sustainable+consumption/production / elements of SCP*

`standards` is deliberately used in plural when not combined with `national OR regional...` to avoid generic use (e.g. "a standard method"). `lifestyles$` is combined in fixed phrases (e.g. `sustainable lifestyle$`) as a NEAR combination with e.g. "environmental" added irrelevant results from medicine (e.g. "environmental and lifestyle factors in this disease").

```py
TS=
(
  ("10 Year Framework of Programmes" OR "10YFP" 
  OR "policy" OR "policies" OR "governmental" OR "governance" OR "action plan$" 
  OR "regulation" OR "regulatory" OR "legal" OR "law$" OR "standards" OR "code$ of conduct" 
  OR "accounting" OR "reporting" 
  OR 
    (
      ("national*" OR "regional*" OR "sector*" OR "international*" OR "multi-level") 
      NEAR/3 ("strateg*" OR "framework$" OR "programme$" OR "program$" OR "plan" OR "planning" OR "plans" OR "target$" OR "goal$" OR "instruments" OR "standard$")
    )
  )
  AND 
      (
        (
          ("sustainab*" OR "environmental*" OR "ecological*" OR "eco" OR "green") 
          NEAR/5 
              ("production" OR "produce$" OR "process*" OR "product$" 
              OR "consumption" OR "consume$" OR "consumer$" 
              OR "retail" OR "retailer$" OR "trade" OR "market*"
              OR "handling" OR "storage" OR "transport*" OR "distribution" OR "packaging" OR "supply chain$" 
              OR "procurement$" OR "acquisition$" OR "purchas*" OR "investment$" 
              OR "resource efficiency" OR "resource use efficiency" OR "material efficiency" OR "material use efficiency" 
              OR ("energy efficien*" NEAR/5 ("housing" OR "building$" OR "construction$")) 
              OR "Sustainable Building and Construction Initiative" OR ("SBCI" NEAR/3 "UNEP") 
              OR "tourism" OR "tourist$" OR "travel*" OR "hospitality" OR "leisure"
              OR "food system$" OR "food production" OR "food consumption" OR "food security" 
              OR "agricultur*" OR "cropping system$" OR "agroforest*" OR "agro forest*" OR "aquaculture" OR "fisher*" OR "fish farm*" 
              OR 
                (
                  ("lifecycle$" OR "life-cycle$" OR "cradle to cradle" OR "cradle-to-cradle" OR "footprint") 
                  NEAR/5 ("material$" OR "service$" OR "analy?is" OR "analy?es" OR "analy?e" OR "assessment$" OR "assess" OR "assessed")
                ) 
              OR 
                (
                  ("waste$" OR "biowaste$" OR "ewaste$" OR "garbage" OR "trash" OR "trashes" OR "litter" OR "rubbish" OR "sewage$" OR "sludge") 
                  NEAR/5 
                      ("management" OR "handling" OR "packaging" OR "labelling" OR "storing" OR "disposal" OR "dispose$" OR "incinerat*" OR "combust*" 
                      OR "collection" OR "collect$" OR "collected" OR "transport*" OR "treatment" OR "processing" OR "processed" OR "end of life" OR "end of chain" 
                      OR "sorting" OR "sort$" OR "sorted"
                      )
                ) 
              )
        ) 
        OR "sustainable lifestyle$" OR "sustainable life style$" OR "green lifestyle$" OR "eco lifestyle$" OR "environmental lifestyle$"
        OR "ecobuilding$"OR "eco-building$"
        OR "ecotourism" OR "eco-tourism"
        OR ("responsib*" NEAR/3 ("tourist$" OR "tourism" OR "consumer$" OR "consumption")) 
        OR "cleaner production"
        OR 
          (
            ("recycl*" OR "re-cycl*" OR "reuse$" OR "re-use$" OR "reusing" OR "re-using" 
            OR "refurbish*" OR "re-furbish*" OR "remanufactur*" OR "re-manufactur*" 
            OR "repurpos*" OR "re-purpos*"  
            OR "compost*" OR "codigest*" OR "co-digest*" 
            OR "resource efficiency" OR "resource use efficiency" OR "material efficiency" OR "material use efficiency" 
            ) 
            NEAR/5 
              ("bioeconom*" OR "bio-econom*" OR "production" OR "produce$" OR "product$" OR "consumption" OR "consume$" OR "consumer$" OR "packaging" 
              OR "sidestream$" OR "side-stream$" OR "byproduct$" OR "by-product$" 
              OR "resource$" OR "material$" OR "matter" OR "biomass" 
              OR "waste$" OR "biowaste$" OR "ewaste$" OR "e-waste$" OR "garbage" OR "trash" OR "trashes" OR "litter" OR "rubbish" OR "sewage$" OR "sludge"
              )
          )
        OR ("circular*" NEAR/5 ("econom*" OR "bioeconom*" OR "bio-econom*" OR "production" OR "produce$" OR "product$" OR "consumption" OR "consume$" OR "consumer$")) 
        OR 
          (
            ("utili*" OR "use" OR "using" OR "usage" OR "design" OR "designed" OR "designing") 
            NEAR/5 ("sidestream$" OR "side-stream$" OR "byproduct$" OR "by-product$")
          ) 
        OR 
          (
            ("design*" OR "technolog*" OR "housing" OR "building$" OR "construction$") 
            NEAR/3 ("green" OR "eco" OR "sustainab*")
          ) 
        OR "ecolabelling" OR "ecolabel$" OR "eco-labelling" OR "eco-labels" OR "environmental label$" 
        OR 
          (
            ("certification" OR "certificate$" OR "label$" OR "labelling") 
            NEAR/5 ("sustainab*" OR "responsib*" OR "environmental*" OR "ecological*" OR "eco" OR "green")
          )
      )
)  
    
```


### Target 12.2

> **12.2 By 2030, achieve the sustainable management and efficient use of natural resources**
> 
> 12.2.1 Material footprint, material footprint per capita, and material footprint per GDP

> 12.2.2 Domestic material consumption, domestic material consumption per capita, and domestic material consumption per GDP

This target is interpreted to cover research about a) sustainable management and use of natural resources, including sustainable food production and b) efficient use of natural resources, with emphasis on efficient material use, including green technologies & design, circularity, footprint and lifecycle analysis. We interpret this target to also be about reducing the use of natural resources and conserving them, e.g. by advancing ecolabelling and environmental certifications.

Sources used for definitions and specifying terms:

* Metadata for indicator 12.2.1 (<a id="UNstats2021">[UN Statistics division, 2021](#f3)</a>) https://unstats.un.org/sdgs/metadata/files/Metadata-12-02-01.pdf 
* UNEP Topic pages for *Resource efficiency* (<a id="UNEPRes">[UNEP Resource efficiency](#f6)</a>) and the RMB_strategy2020.pdf found on this page. 
* UNEP publication *ABC to SCP* (<a id="ABC">[UNEP, 2010](#f1)</a>)

#### Phrase 1

This phrase aims to find research about sustainable management of natural resources, such as forests, oceans, land, water, minerals and fuels. A specific sentence for sustainable forest management, used in SDG 15 target 15.2, is included in the phrase. 

As the `fossil fuels` are also natural resources (nonrenewable) we considered including the sustainable use of them. After a discussion with a specialist, we decided not to include them in this phrase. Instead, phrase 4 searches for reducing the use of fossil fuels.  

Term `water` does not appear as a single standing term because e.g. "water use" is related to many phenomena which are not relevant to the SDG 12. 

The combination of `environmental` and `development` brings some irrelevant results about e.g. ecological community development under different natural environmental conditions. But this combination is also central for many relevant papers about this target, e.g. environmental land use development. We were unable to find a suitable sentence for excluding irrelevant results without losing many relevant ones.


The elements of the phrase are *sustainable+management + natural resources*.

```py 
TS=
( 
  (
    (
      (
        ("sustainab*" OR "responsib*" OR "environmental*" OR "ecological*" OR "eco" OR "green") 
        NEAR/3 
            ("manag*" OR "extract*" OR "practice$" OR "resource us*" OR "usage" OR "consumption" OR "consume$" OR "consumer$"
            OR "govern*" OR "development" OR "administrat*" OR "plan" OR "planning" OR "policy" OR "policies"
            )
      )
      NEAR/15
          (
            (("natural" OR "renewable" OR "*newable") NEAR/3 ("resource$" OR "material$")) 
            OR "natural capital" 
            OR "raw material$" 
            OR "*forest*" OR "woodland$"
            OR "ocean$" OR "marine" OR "fresh water$" OR "lake$" OR "river$" OR "coastal" 
            OR "fishery" OR "fisheries" OR "fish farm$"  
            OR "wildlife" OR "hunt*"
            OR "water supply" OR "water supplies" OR "water resource$" OR "freshwater resource$" OR "suppl* of freshwater"
            OR ("water" NEAR/3 "management") 
            OR "land" OR "soil$" 
            OR "mineral$" OR "metal$" OR "ore$"
          )
    ) 
    OR 
      (
          ("sustainabl*" OR "responsib*" OR "environmental*" OR "ecological*" OR "eco" OR "long-term management plan")
          NEAR/5 ("forestry" OR "silvicultur*" OR "arboricultur*" OR "logging" OR "mining") 
      )
    OR ("water" NEAR/3 ("sustainabl$" NEAR/3 "use")) 
    OR "Global Forest Goals"  
    OR "Forest under certification"
    OR "Certified forest area"
    OR "International Resource Panel"
  )    
)
```

#### Phrase 2

This phrase aims to find research about unsustainable/irresponsible/inefficient management and use of natural resources, such as forests, oceans, land, water, minerals or fuels. The elements of the phrase are *unsustainable use/practises + natural resources*.

Term `irresponsible` is not combined with the use of `fossil fuels` and `energy sources` in order to avoid irrelevant results. Term `water` does not appear as a single standing term because e.g. "water use" is related to many phenomena which are not relevant to the SDG 12. 

```py 
TS=
( 
  (
    (
      (
        ("unsustainab*" OR "irresponsib*" OR "unecological*")
        NEAR/3 ("manag*" OR "use" OR "using" OR "usage" OR "utili*" OR "consumption" OR "consume$" OR "consumer$" OR "extract*" OR "govern*" OR "development" OR "administrat*" OR "planning" OR "policy" OR "policies")
      ) 
      OR ("inefficien*" NEAR/3 ("use" OR "using" OR "usage" OR "utili*"))
    )
    NEAR/15
        (
          (("natural" OR "renewable" OR "*newable") NEAR/3 ("resource$" OR "material$")) 
          OR "natural capital" 
          OR "raw material$" 
          OR "*forest*" OR "woodland$"
          OR "ocean$" OR "marine" OR "fresh water$" OR "lake$" OR "river$" OR "coastal" 
          OR "fishery" OR "fisheries" OR "fish farm$" 
          OR "wildlife" OR "hunt*"
          OR "water supply" OR "water supplies" OR "water resource$" OR "freshwater resource$" OR "suppl* of freshwater" OR "water management"
          OR "land" OR "soil$" 
          OR "mineral$" OR "metal$" OR "ore$"
          OR "fossil fuel$" OR "coal" OR "oil" OR "natural gas" OR "peat" OR "diesel fuel" OR "gasoline" OR "kerosene" OR "petroleum" OR "energy source$"
        )
  )
  OR 
  (
    ("unsustainabl*" OR "irresponsib*" OR "unecological*")
    NEAR/5 ("forestry" OR "silvicultur*" OR "arboricultur*" OR "logging" OR "mining") 
  )
  OR ("water" NEAR/3 "unsustainable us*")      
)
```

#### Phrase 3

This phrase aims to find research about efficient use of natural resources, including e.g. circular economy, recycling materials and material footprint analyses. It also searches for saving/conserving natural resources, eco-labelling and environmental certification included. 

By the indicators of this target, it was interpreted to urge to understand the material footprint of commodities. This is why we have not linked `material/product lifecycles` to natural resources, but left them to be found independently. Term `footprint analysis`, however, is linked with natural resources in order to exclude irrelevant results about e.g. analysis of human feet. The footprint/lifecycles sentence is in two parts to reduce noise which in other phrases about footprint/lifecycle analysis (12.1.1&2, 12.5.2, 12.8.2 and 12.a.1) is controlled by linkage to `sustainability`. Even still, `lifecycles` brings some irrelevant results about e.g. lifecycles of animals.  

After a discussion with a specialist we concluded that `circular economy` does not need to be combined with `natural resources` since (as far as we understand) circular economy is always about using (either renewable on nonrenewable) natural resources one way or another. Terms refering to `recycling` are linked to a set of related terms in order to exclude results from fields not relevant to SDG 12.

The elements of the phrase are *circularity/recycling/material lifecycles/ecolabelling OR efficient use/sustainable consumption/footprint + natural resources*

`mining` is not used here as in phrases 1 and 2, as it mostly returns irrelevant extra results about e.g. pattern mining, opinion mining.

```py 
TS=
(
      ("circular*" NEAR/5 ("econom*" OR "bioeconom*" OR "bio-econom*" OR "production" OR "produce$" OR "product$" OR "consumption" OR "consume$" OR "consumer$")) 
      OR 
        (
          ("recycl*" OR "re-cycl*" OR "reuse$" OR "re-use$" OR "reusing" OR "re-using"
          OR "refurbish*" OR "re-furbish*" OR "remanufactur*" OR "re-manufactur*"  
          OR "repurpos*" OR "re-purpos*" 
          OR "compost*" OR "codigest*" OR "co-digest*" 
          OR "resource efficiency" OR "resource use efficiency" OR "material efficiency" OR "material use efficiency"
          ) 
          NEAR/5 
              ("bioeconom*" OR "bio-econom*" OR "production" OR "produce$" OR "product$" OR "consumption" OR "consume$" OR "consumer$" 
              OR "packaging" OR "sidestream$" OR "side-stream$" OR "byproduct$" OR "by-product$" 
              OR "resource$" OR "material$" OR "matter" OR "biomass" 
              OR "waste$" OR "biowaste$" OR "ewaste$" OR "e-waste$" OR "garbage" OR "trash" OR "trashes" OR "litter" OR "rubbish" OR "sewage$" OR "sludge"
              )
        )
      OR 
        (
          ("lifecycle$" OR "life-cycle$" OR "cradle to cradle" OR "cradle-to-cradle" OR "footprint") 
          NEAR/5 ("material$" OR "product$" OR "production" OR "produce$" OR "service$" OR "consumption" OR "consume$" OR "consumer$")
        ) 
      OR
        (
          (
            (
              ("utili*" OR "use" OR "using" OR "usage" OR "design" OR "designed" OR "designing") 
              NEAR/5 ("sidestream$" OR "side-stream$" OR "byproduct$" OR "by-product$")
            )
          OR (("saving" OR "save$" OR "conserv*" OR "efficien*") NEAR/5 ("use" OR "using" OR "usage" OR "utili*" OR "consumption"))   
          OR ("footprint" NEAR/3 ("analy?is" OR "analy?es" OR "analy?e" OR "assessment$" OR "assess" OR "assessed"))  
          OR "ecolabel*" OR "eco-label*" OR "environmental label$" 
          OR 
            (
              ("certification" OR "certificate$" OR "label$" OR "labelling") 
              NEAR/5 ("sustainab*" OR "responsib*" OR "environmental*" OR "ecological*" OR "eco" OR "green")
            )    
          )
          NEAR/5 
            (
              (("natural" OR "renewable" OR "*newable") NEAR/3 ("resource$" OR "material$")) 
              OR "natural capital" 
              OR "raw material$" 
              OR "*forest*" OR "woodland$" OR "silvicultur*" OR "arboricultur*" 
              OR "ocean$" OR "marine" OR "fresh water$" OR "lake$" OR "river$" OR "coastal" 
              OR "fishery" OR "fisheries" OR "fish farm$"  
              OR "wildlife" OR "hunt*"
              OR "water supply" OR "water supplies" OR "water resource$" OR "freshwater resource$" OR "suppl* of freshwater"
              OR "land" OR "soil$" 
              OR "mineral$" OR "metal$" OR "ore$"
            )    
        ) 
)

```

#### Phrase 4

This phrase aims to find research about reducing the use and exploitation of natural resources and fossil fuels and the waste involved in the use of them. The elements of the phrase are *action(reduce) + material footprint OR use/waste + natural resources/fossil fuels*. The phrase is identical to the corresponding action approach phrase (BAA 12.2 phrase 4).

Some of the sources for natural resources (e.g. `marine` and `minerals`) are linked with terms `resources` or `materials` in order to reduce noise (e.g. "land use" OR "marine habitat use").

```py 
TS=
(
  ("reduc*" OR "decreas*" OR "minimi*" OR "combat*" OR "avoid*") 
  NEAR/5 
    ("material footprint" OR "domestic material consumption" OR "ecological footprint" OR "resource footprint"
    OR
      (
        ("use" OR "use" OR "using" OR "usage" OR "utili*" OR "extract*" OR "consumption" OR "consume$" 
        OR "depletion" OR "deplete$" OR "exploit*"
        OR "waste$"
        ) 
        NEAR/5 
            (
              (("natural" OR "renewable" OR "*newable" OR "ocean$" OR "marine" OR "fresh water$" OR "lake$" OR "river$" OR "coastal" OR "mineral$" OR "land" OR "soil$") 
              NEAR/5 ("resource$" OR "material$")
              ) 
              OR "natural capital" 
              OR "raw material$" 
              OR "*forest*" OR "woodland$" OR "silvicultur*" OR "arboricultur*"  
              OR "fishery" OR "fisheries" OR "fish farm$"  
              OR "wildlife" OR "hunt*"
              OR "water supply" OR "water supplies" OR "water resource$" OR "freshwater resource$" OR "suppl* of freshwater"
              OR "metal$" OR "ore$" 
              OR "fossil fuel$" OR "coal" OR "oil" OR "natural gas" OR "peat" OR "diesel" OR "gasoline" OR "kerosene" OR "petroleum"
            ) 
      )
    )
)
```

#### Phrase 5

This phrase aims to find research about sustainable food production. It is identical to the SDG 2 target 2.4 phrase 4 - documentation for the agricultural terms can be found there. 

`ecoagricultur*` is a relatively specialist term for ecology and agriculture and considered narrow enough to use alone.

*Sustainability terms*: `agroecolog*` (agroecology, or the agroecological approach) is considered a relevant term for sustainable, being related to ecology and environmental stability as well as social and cultural dimensions (<a id="SFS">[One Planet network Sustainable Food Systems (SFS) Programme, 2020, p. 28](#f8)</a>). Other terms for practices/approaches that can be considered to contribute to "sustainable food production systems" were gathered from <a id="HLPE">[High Level Panel of Experts on Food Security and Nutrition (2019, Appendix 1 and p. 36)](#f14)</a>; some of these also are relevant for soil quality. Other terms from this source are included in other phrases: "sustainable intensification" is covered in phrase 1, "climate smart agriculture" in phrase 2. `organic` must be combined due to use in other contexts (e.g. soil organic matter, organic carbon).

The elements of the phrase are *ecoagriculture OR (food production systems + sustainability + action)*

```py
TS=
  ("ecoagricultur*" OR "eco-agricultur*" OR "permaculture"
  OR "conservation agriculture" OR "conservation farming"
  )
OR
TS=
(
  (
    ("food production" OR "food grower$" OR "agro food" OR "agrifood" OR "agri food"
    OR "farm*" OR "agricultur*" OR "smallhold*" OR "small hold*"
    OR "cropping system$" OR "orchard$" OR "arable land$" OR "pasture$" OR "pastoral*"
    OR "agroforest*" OR "agro forest*" OR "silvopastur*" OR "silvopastoral*"
    OR "aquaculture" OR "fisher*" OR "fish farm*" OR "mariculture"
    OR "fodder" OR "animal feed" OR "fish feed"
    OR
      (
        ("crop$" OR "grain$" OR "vegetable$" OR "fruit$" OR "cereal$" OR "rice" OR "wheat" OR "maize" OR "pulses" OR "legume$"
        OR "livestock" OR "fish" OR "cattle" OR "sheep" OR "poultry" OR "pig$" OR "goat$" OR "chicken$" OR "buffalo*" OR "duck$"
        )
        NEAR/5 ("production" OR "producer$" OR "grower$" OR "herder$" OR "herding" OR "ranch*" OR "plantation$")
      )      
    )
    NEAR/15
        ("sustainab*" OR "agroecolog*" OR "eco-friendly" OR "environmentally friendly" OR "ecosystem approach" OR "ecosystem based" 
        OR ("organic" NEAR/3 ("farm*" OR "agricultur*" OR "cultivation" OR "gardening" OR "production" OR "orchard$" OR "pasture$" OR "aquaculture"))
        OR "natural pest control" OR "natural pest management" OR "biological pest control" OR "intergrated pest management"
        OR "intercropping" OR "cover crop$" OR "crop rotation" OR "polyculture$" OR "permaculture"
        OR "reduced tillage" OR "mulch" OR "mulching"
        OR "water conservation"       
        )   
  )
  NOT ("solar farm*" OR "wind farm*" OR "power farm*")  
)
```

### Target 12.3

> **12.3 By 2030, halve per capita global food waste at the retail and consumer levels and reduce food losses along production and supply chains, including post-harvest losses**
> 
> 12.3.1 (a) Food loss index and (b) food waste index

This target is interpreted to cover research about food loss on all levels from food production, to supply chains, retail and consumer levels. We interpret it to also cover capacity building for preventing food loss as mentioned in the FAO *Initiative on Food Loss and Waste Reduction* (<a id="FAO">[FAO Global Initiative on Food Loss](#f9)</a>). 

Although the target specifies levels where food loss happens (production, supply chains, retail, consumer) we have not restricted phrase 1 with these. It would narrow down the results because not all relevant articles about food loss mention any of those terms. Phrase 2 searches for waste on specified levels of food production/retail/consumption. 

`food loss` or `food losses` are used as a fixed term in all phrases to avoid various irrelevant articles about animal nutrition and human health brought by `food` NEAR `loss`. Even still, the phrase returns some irrelevant articles about animal nutrition and human health. The irrelevant articles are found particularly from prior to 2015. 

#### Phrase 1

This phrase aims to find research about food loss and waste on all levels. The elements of the phrase are *food loss*.

Terms for food loss are mostly from the metadata for FAO indicator 12.3.1 (<a id="UNstats2021">[UN Statistics division, 2021](#f3)</a>) https://unstats.un.org/sdgs/metadata/files/Metadata-12-03-01A.pdf . Terms refering to `inedible parts` or `non-edible parts` were not included in the phrase - although they are mentioned in the metadata for UNEP 12.3.1 indicator  (<a id="UNstats2021">[UN Statistics division, 2021](#f3)</a>) https://unstats.un.org/sdgs/metadata/files/Metadata-12-03-01B.pdf. The terms brought irrelevant results about animal feeding choises and a majority of relevant results would have been found with the term `waste` which is included in the search phrase.

Terms `weight loss` and `obesity` are added in the phrase with `NOT` to exclude irrelevant results about food & weight loss, as well as `insecurity` to exclude articles about food insecurity (loss of lives close to "food") and `food intake` and `body weight` to exclude articles about animal nutrition. 

```py 
TS=
(
  (
      ("food loss" OR "food losses" 
      OR 
        (
          ("food" OR "fodder" OR "animal feed" OR "fish feed") 
          NEAR/3 ("lost" OR "waste$" OR "spoiled" OR "discard*" OR "incinerat*" OR "combust*" OR "perishable")
        )
      )
  ) 
NOT (("weightloss" OR "weight loss" OR "loss of weight" OR "body weight" OR "obesity" OR "insecurity" OR ("food" NEAR/3 "intake")) NOT ("food loss" OR "food waste"))
)
```

#### Phrase 2

This phrase aims to find research about waste in food production/processing/supply chains/retail/consumption. The elements of the phrase are *waste/loss + food production/processing/supply chains/retail/consumption*.

The metadata for FAO indicator 12.3.1 (<a id="UNstats2021">[UN Statistics division, 2021](#f3)</a>) https://unstats.un.org/sdgs/metadata/files/Metadata-12-03-01A.pdf was used to find most of the specifying terms for food commodities and levels of handling food (harvest, slaughter, storage, transportation, processing, packaging, retail). Terms for food handling were found also from UNEP *Global Chemicals and Waste Indicator Review Document* (<a id="UNEPchemicals">[UNEP, 2021](#f11)</a>).

Terms `weight loss` and `obesity` are added in the phrase with `NOT` to exclude irrelevant results about food & weight loss, as well as `insecurity` to exclude articles about food insecurity (loss of lives close to "food") and `food intake` and `body weight` to exclude articles about animal nutrition.

```py 
TS=
(
  (
    ("waste$" OR "loss" OR "losses" OR "lost" OR "spoiled" OR "discard*" OR "incinerat*" OR "combust*") 
    NEAR/5 
        (
          ("cereal$" OR "pulses" OR "fruit$" OR "berry" OR "berries" OR "vegetable$" OR "root crop$" OR "oil bearing crop$" OR "soybean$" OR "lentil$" OR "chickpea$" OR "legume$"
          OR "crop$" OR "grain$" OR "rice" OR "wheat" OR "maize" OR "livestock" OR "fish" OR "cattle" OR "sheep" OR "poultry" OR "pig$" OR "goat$" OR "chicken$" OR "buffalo*" OR "duck$"
          OR "dairy waste" OR "discard* milk"
          OR "harvest*" OR "slaughter*"
          ) 
          NEAR/5 
              ("production" OR "processing" OR "handling" OR "storage" OR "transport*" OR "distribution" OR "market*" OR "packaging" OR "supply chain$" 
              OR "retail" OR "food service" OR "foodservice" OR "restaurant*" OR "household" OR "consumer$" OR "consumption" OR "consume$"
              OR "harvest*" OR "slaughter*"
              )
        )
  )
NOT (("weightloss" OR "weight loss" OR "loss of weight" OR "body weight" OR "obesity" OR "insecurity" OR ("food" NEAR/3 "intake")) NOT ("food loss" OR "food waste"))
)

```

### Target 12.4

> **12.4 By 2020, achieve the environmentally sound management of chemicals and all wastes throughout their life cycle, in accordance with agreed international frameworks, and significantly reduce their release to air, water and soil in order to minimize their adverse impacts on human health and the environment**
> 
> 12.4.1 Number of parties to international multilateral environmental agreements on hazardous waste, and other chemicals that meet their commitments and obligations in transmitting information as required by each relevant agreement

> 12.4.2 (a) Hazardous waste generated per capita; and (b) proportion of hazardous waste treated, by type of treatment

This target is interpreted to cover research about:
- sustainable/environmentally sound management of chemicals throughout their life cycle, including international agreements on chemical management (phrase 1 and 2)
- sustainable management of all wastes, including international agreements on management of hazardous wastes (phrase 2)
- reducing the release of chemicals and hazardous wastes to the air, water and soil (phrase 3)
- reducing the risks of chemicals and hazardous wastes to human health or the environment (phrase 4)
- unsustainable management of chemicals and waste (phrase 5)

UN topic page for *Chemicals and waste* (<a id="chemicals">[UN Topics Chemicals and waste](#f10)</a>) and UNEP *Global Chemicals and Waste Indicator Review Document* (<a id="UNEPchemicals">[UNEP, 2021, p. 65](#f11)</a>) as well as *Basel Convention Annex VIII* (<a id="UNEPBasel">[UNEP Basel Convention](#f12)</a>) and UNEP webpage *Persistent Organic Pollutants (POPs) and Pesticides* (<a id="UNEPPOPs">[UNEP POPs](#f17)</a>) were used as a source for terms and definitions. Some chemicals were also found from the Finnish Food Authority Chemical webpages https://www.ruokavirasto.fi/en/themes/risk-assessment/risk-assessment-of-food-safety/chemistry/. The indicators for 12.4 emphasise hazardous wastes and chemicals. For this reason the focus is on terms for hazardous chemicals (e.g. POPs) and household wastes (paints, polish, cleaning products, engine oil).

Some specifying terms for wastes were found from the UN topic page for *Chemicals and waste* (<a id="chemicals">[UN Topics Chemicals and waste](#f10)</a>) and specifying terms for waste management from the UNEP *Global Chemicals and Waste Indicator Review Document* (<a id="UNEPchemicals">[UNEP, 2021](#f11)</a>).

#### Phrase 1

The aim of this phrase is to find research about sustainable management of chemicals and plastic thoughout their life cycle, and about international agreements on chemical management. The elements of the phrase are *sustainable + management + chemicals / international agreements*.

International agreements included in the phrase are mentioned on the UN topic page for *Chemicals and waste* (<a id="chemicals">[UN Topics Chemicals and waste](#f10)</a>). 

```py 
TS=
(
  "Dubai Declaration on International Chemicals Management" 
  OR "Strategic Approach to International Chemicals Management" OR "SAICM"
  OR
  (
    ("cradle to cradle" OR "cradle-to-cradle" OR "lifecycle analysis" OR "life-cycle analysis" OR "lifecycle assessment" OR "life-cycle assessment"
    OR
      (
        ("sustainab*" OR "responsib*" OR "environmental*" OR "ecological*" OR "eco" OR "green" OR "safe" OR "safety" OR "safely") 
        NEAR/5 
            ("lifecycle$" OR "life-cycle$" OR "end of life" 
            OR "management" OR "handling" OR "packaging" OR "labelling" OR "storage" OR "storing" OR "stored"
            OR "disposal" OR "dispose$" OR "transport*" OR "process*" 
            OR "use$" OR "using" OR "utilisa*" OR "utiliza*" OR "production"
            )
      ) 
    )
    NEAR/5 
      ("chemical$" OR "paint$" OR "polish*" OR "cleaning product$" OR "engine oil" OR "plastic$" OR "microplastic$" OR "nanoplastic$" OR "nanomaterial$" 
      OR "pesticide$" OR "herbicide$" OR "insecticide$" OR "fungicide$" 
      OR "solvent$" OR "etching solutions" OR "battery" OR "batteries" OR "accumulator$" 
      OR "medicinal residues" OR "toxic moulds" 
      OR "Antimony" OR "Arsenic" OR "Beryllium" OR "Cadmium" OR "Lead" OR "Mercury" OR "Selenium" OR "Tellurium" OR "Thallium" OR "Zinc" OR "Jarosite" OR "Hematite" OR "Copper" OR "cupric chloride" OR "organohalogen$" OR "heavy metals" OR "toxic metal$" OR "acrylamide$" OR "persistent organic pollutants" OR "POP compounds" OR "aldrin" OR "chlordane" OR "DDT" OR "dieldrin" OR "endrin" OR "heptachlor" OR "hexachlorobenzen" OR "mirex" OR "polychlorinated biphenyls" OR "polychlorinated dibenzo-p-dioxins" OR "polychlorinated dibenzofurans" OR "toxaphen" OR "neonicotinoid$"
      )  
  )
)
```

#### Phrase 2

The aim of this phrase is to find research about sustainable waste management including recycling, and about international agreements on hazardous wastes. The elements of the phrase are *international agreements / recycling/sustainable+management + wastes*.

International agreements were taken from the metadata for indicator 12.4.1. (<a id="UNstats2021">[UN Statistics division, 2021](#f3)</a>) https://unstats.un.org/sdgs/metadata/files/Metadata-12-04-01.pdf. 

`Recycling` terms are not restricted by sustainability string since recycling is understood as sustainable waste management in itself. According to metadata for indicator 12.5.1 (<a id="UNstats2021">[UN Statistics division, 2021](#f3)</a>) https://unstats.un.org/sdgs/metadata/files/Metadata-12-05-01.pdf `composting` and `codigestion` are included in recycling, but `combustion`not. The structure of this phrase reflects this definition.

```py 
TS=
(
  "Basel Convention" OR "Rotterdam Convention" OR "Stockholm Convention" OR "Montreal Protocol" OR "Minamata Convention" OR "Bamako Convention"
  OR
    (
      ("recycl*" OR "re-cycl*" OR "compost*" OR "codigest*" OR "co digest*" 
      OR "reuse$" OR "re-use$" OR "reusing" OR "re-using" OR "repurpos*" OR "re-purpos*" 
      OR "refurbish*" OR "re-furbish*" OR "remanufactur*" OR "re-manufactur*"
      OR "cradle to cradle" OR "cradle-to-cradle" OR "lifecycle analysis" OR "life-cycle analysis" OR "lifecycle assessment" OR "life-cycle assessment"
      OR
        (
          ("sustainab*" OR "responsib*" OR "environmental*" OR "ecological*" OR "eco" OR "green" OR "safe" OR "safety" OR "safely") 
          NEAR/5 
              ("lifecycle$" OR "life-cycle$" OR "end of life"
              OR "management" OR "handling" OR "packaging" OR "labelling" OR "storage" OR "storing" OR "stored"
              OR "disposal" OR "dispose$" OR "transport*" OR "process*" 
              OR "incinerat*" OR "combust*" OR "collect*" OR "treatment" OR "sorting" OR "sorted"
              ) 
        ) 
      )
    ) 
    NEAR/5 
      ("waste$" OR "biowaste$" OR "ewaste$" OR "e-waste$" OR "garbage" OR "trash" OR "trashes" OR "litter" OR "rubbish" OR "sewage$" OR "sludge" 
      OR "street sweepings" 
      OR "construction debris" OR "demolition debris"
      ) 
)
```

#### Phrase 3

This phrase aims to find research about reducing releases of chemicals and wastes into the environment. The elements of the phrase are *action + releases/emissions + chemicals/wastes*.

This phrase is identical to the corresponding action approach phrase (BAA 12.4 phrase 3).

```py
TS=
(
  ("reduc*" OR "minim*" OR "decreas*" OR "stop*" OR "end" OR "ends" OR "ended" OR "ending"
  OR "avoid*" OR "prevent*" OR "combat*" OR "tackl*" OR "halt*" OR "resist*" OR "lowering" OR "lower$" OR "lowered" 
  OR "prohibit*" OR "cleanup" OR "clean up"
  ) 
  NEAR/5 
    (
      ("releas*" OR "emission$" OR "effluent$" OR "discharge$" OR "pollution" OR "pollutant" OR "pollute$" OR "contamination") 
      NEAR/5 
          ("chemical$" OR "paint$" OR "polish*" OR "cleaning product$" OR "engine oil" OR "plastic$" OR "microplastic$" OR "nanoplastic$" OR "nanomaterial$" OR "pesticide$" OR "herbicide$" OR "insecticide$" OR "fungicide$" OR "solvent$" OR "etching solutions" OR "battery" OR "batteries" OR "accumulator$" OR "medicinal residues" OR "toxic moulds" 
          OR "Antimony" OR "Arsenic" OR "Beryllium" OR "Cadmium" OR "Lead" OR "Mercury" OR "Selenium" OR "Tellurium" OR "Thallium" OR "Zinc" OR "Jarosite" OR "Hematite" OR "Copper" OR "cupric chloride" OR "organohalogen$" OR "heavy metals" OR "toxic metal$" OR "acrylamide$" OR "persistent organic pollutants" OR "POP compounds" OR "aldrin" OR "chlordane" OR "DDT" OR "dieldrin" OR "endrin" OR "heptachlor" OR "hexachlorobenzen" OR "mirex" OR "polychlorinated biphenyls" OR "polychlorinated dibenzo-p-dioxins" OR "polychlorinated dibenzofurans" OR "toxaphen" OR "neonicotinoid$" 
          OR "waste$" OR "ewaste$" OR "e-waste$" OR "garbage" OR "trash" OR "trashes" OR "litter" OR "rubbish" OR "sewage$" OR "sludge"
          )   
    )
)

```

#### Phrase 4

This phrase aims to find research about reducing/controling/assessing risks which chemicals and all wastes cause to human health and environment. The elements of the phrase are *action + risks/hazards + health/environment + chemicals/wastes*

The phrase is identical to the corresponding action approach phrase (BAA 12.4 phrase 4).

```py
TS=
(
  ("reduc*" OR "minim*" OR "decreas*" OR "prevent*" OR "tackl*" OR "resist*" OR "lowering" OR "lower$" OR "lowered" 
  OR "control*" OR "assess*" OR "evaluat*" OR "monitor*"
  ) 
  NEAR/5 
    (
      (
        ("risk$" OR "hazard$" OR "danger*" OR "advers*" OR "negativ*" OR "harmful*") 
        NEAR/5 ("health" OR "wellbeing" OR "well being" OR "environment")
      ) 
      NEAR/15 
        ("chemical$" OR "paint$" OR "polish*" OR "cleaning product$" OR "engine oil" OR "plastic$" OR "microplastic$" OR "nanoplastic$" OR "nanomaterial$" OR "pesticide$" OR "herbicide$" OR "insecticide$" OR "fungicide$" OR "solvent$" OR "etching solutions" OR "battery" OR "batteries" OR "accumulator$" OR "medicinal residues" OR "toxic moulds" 
        OR "Antimony" OR "Arsenic" OR "Beryllium" OR "Cadmium" OR "Lead" OR "Mercury" OR "Selenium" OR "Tellurium" OR "Thallium" OR "Zinc" OR "Jarosite" OR "Hematite" OR "Copper" OR "cupric chloride" OR "organohalogen$" OR "heavy metals" OR "toxic metal$" OR "acrylamide$" OR "persistent organic pollutants" OR "POP compounds" OR "aldrin" OR "chlordane" OR "DDT" OR "dieldrin" OR "endrin" OR "heptachlor" OR "hexachlorobenzen" OR "mirex" OR "polychlorinated biphenyls" OR "polychlorinated dibenzo-p-dioxins" OR "polychlorinated dibenzofurans" OR "toxaphen" OR "neonicotinoid$" 
        OR "waste$" OR "ewaste$" OR "e-waste$" OR "garbage" OR "trash" OR "trashes" OR "litter" OR "rubbish" OR "sewage$" OR "sludge"
        ) 
    )
)
```

#### Phrase 5

The aim of this phrase is to find research about unsustainable management of chemicals thoughout their life cycle as well as unsustainable waste management. The elements of the phrase are *unsustainable+management + chemicals/waste*.

In order to exclude irrelevant articles where `lead` is used as a verb, a NOT sentence is added to the phrase.

```py 
TS=
(
  (
    (
      ("unsustainab*" OR "irresponsib*" OR "unecological*" OR "unsafe") 
      NEAR/5 
          ("management" OR "life cycle" OR ("life" NEAR/3 "cycle$") OR "disposal" OR "transport*" OR "process*" 
          OR "storage" OR "storing" OR "stored" OR "use" OR "use$" OR "using" OR "utilie$" OR "production"
          OR "handling" OR "transport*" OR "packaging" 
          OR "dispose$" OR "incinerat*" OR "combust*" 
          OR "collection" OR "collect$" OR "collected" OR "treatment" OR "processing" OR "processed" 
          OR "sorting" OR "sort$" OR "sorted" OR "labelling" 
          ) 
    ) 
    NEAR/5 
      ("chemical$" OR "paint$" OR "polish*" OR "cleaning product$" OR "engine oil" OR "plastic$" OR "microplastic$" OR "nanoplastic$" OR "nanomaterial$" OR "pesticide$" OR "herbicide$" OR "insecticide$" OR "fungicide$" OR "solvent$" OR "etching solutions" OR "battery" OR "batteries" OR "accumulator$" OR "medicinal residues" OR "toxic moulds" 
      OR "Antimony" OR "Arsenic" OR "Beryllium" OR "Cadmium" OR "Lead" OR "Mercury" OR "Selenium" OR "Tellurium" OR "Thallium" OR "Zinc" OR "Jarosite" OR "Hematite" OR "Copper" OR "cupric chloride" OR "organohalogen$" OR "heavy metals" OR "toxic metal$" OR "acrylamide$" OR "persistent organic pollutants" OR "POP compounds" OR "aldrin" OR "chlordane" OR "DDT" OR "dieldrin" OR "endrin" OR "heptachlor" OR "hexachlorobenzen" OR "mirex" OR "polychlorinated biphenyls" OR "polychlorinated dibenzo-p-dioxins" OR "polychlorinated dibenzofurans" OR "toxaphen" OR "neonicotinoid$"
      OR "waste$" OR "biowaste$" OR "ewaste$" OR "e waste$" OR "e-waste$" OR "garbage" OR "trash" OR "trashes" OR "litter" OR "rubbish" OR "sewage$" OR "sludge" 
      OR "street sweepings" 
      OR "construction debris" OR "demolition debris"
      )  
  ) 
  NOT ("lead to")
)
```


### Target 12.5

> **12.5 By 2030, substantially reduce waste generation through prevention, reduction, recycling and reuse**
> 
> 12.5.1 National recycling rate, tons of material recycled

This target is interpreted to cover research about reducing/preventing waste (municipal, commercial, etc.), about waste generation, and about recycling. We consider this to also cover research about the circular economy and sidestreams. Some terms for waste generators are taken from indicator 12.5.1 documentation (<a id="UNstats2021">[UN Statistics division, 2021](#f3)</a>) https://unstats.un.org/sdgs/metadata/files/Metadata-12-05-01.pdf.

The themes of this target are also addressed in target **12.2 phrases 3 and 4** about efficient use of natural resources and reducing waste involved in using them, as well as in target **12.3 phrases 1 and 3** about food loss and waste in food production. Recycling of wastes is also included in target **12.4 phrase 2**.

#### Phrase 1

This phrase aims to find research about reducing waste, and about waste generation. The elements of the phrase are *action + wastes/waste generation/types of waste // waste generation*. The action element was retained for wastes in the topic approach, as all research about any kind of waste was too broad given our interpretation - however, the phrase is broader than the action approach in that research about waste generation requires no action. Some terms are combined with *household/municipal/industry* terms because they are used generically (e.g. economic waste; waste of time; garbage logic). 

```py 
TS=
(
  ("reduc*" OR "minim*" OR "decreas*" OR "stop*" OR "end" OR "ends" OR "ended" OR "ending" OR "eliminat*"
  OR "avoid*" OR "prevent*" OR "combat*" OR "tackl*" OR "halt*" OR "resist" OR "resisting" OR "lowering" OR "lower$" OR "lowered"
  ) 
  NEAR/5 
      ("agrowaste" OR "solid waste$" OR "bio-waste" OR "biowaste$" 
      OR "ewaste$" OR "e-waste$" OR "electronic waste$" 
      OR "rubbish" OR "sewage$" OR "street sweepings"
      OR
        (
          ("waste$" OR "sludge" OR "litter" OR "trash" OR "garbage") 
          NEAR/5 
              ("generation" OR "generated" 
              OR "household$" OR "domestic" OR "residential"
              OR "commerce" OR "commercial" OR "trade" OR "business*" OR "office$" 
              OR "institution$" OR "schools" OR "hospital$" OR "municipal*" OR "urban" OR "cities"
              OR "industr*" OR "manufacturing" OR "hotel$" OR "restaurant$" 
              )
        )
      )
)
OR
TS=
(
  ("waste$" OR "sludge" OR "litter" OR "trash" OR "garbage"
  OR "agrowaste" OR "solid waste$" OR "bio-waste" OR "biowaste$" 
  OR "ewaste$" OR "e-waste$" OR "electronic waste$" 
  OR "rubbish" OR "sewage$" OR "street sweepings"
  )
  NEAR/5 ("generation" OR "generated")
)

```

#### Phrase 2

This phrase aims to find research about recycling, reuse, circular economy and utilizing sidestreams. The elements of the phrase are a list of various activities that could reduce waste, and these terms are combined with terms for waste/sidestreams, terms for consumption and production, or terms for sustainability.

Because terms for many activities that can reduce waste (e.g. `recycle` `reuse` and `resource efficiency`) have meanings in fields not relevant to this target, they are combined with a string of terms related to the target (e.g. production, consumption, bioeconomy, waste). Unfortunately, limiting `recycling` like this leaves out many relevant papers which do not mention these terms but talk on a more specific level (e.g. recycling bottles, paper, etc.). And even with the limitation, some irrelevant papers about e.g. electronics and cell biology are still found by this phrase. 

Term `compost` is removed from the phrase to focus on articles about reducing waste instead of articles about composting in general. Promoting circular use of natural resources, including composting, is covered by target 12.2. We include `zero-waste` as a stand-alone term, since it refers to the idea of preventing waste products in the first place (i.e. waste generation). Terms such as `material efficiency` are combined with *waste* terms because alone they are more relevant to 12.2 - however, the ideas within could still be relevant to reducing waste. 

```py
TS=
(
    (
      ("recycl*" OR "re-cycl*" OR "reuse$" OR "re-use$" OR "reusing" OR "re-using" 
      OR "refurbish" OR "re-furbish*" OR "remanufactur*" OR "re-manufactur*" OR "repurpos*" OR "re-purpos" 
      OR "codigest*" OR "co-digest*"
      OR "resource efficiency" OR "resource use efficiency" OR "material efficiency" OR "material use efficiency"
      OR "lifecycle$" OR "life-cycle$" OR "cradle to cradle" OR "cradle-to-cradle" OR "material footprint" OR "resource footprint"
      OR "cleaner production"
      ) 
      NEAR/15 
        ("sidestream$" OR "side-stream$" OR "byproduct$" OR "by-product$" 
        OR "waste$" OR "agrowaste" OR "solid waste$" OR "biowaste$" OR "ewaste$" OR "e-waste$" OR "garbage" OR "trash" OR "trashes" OR "litter" OR "rubbish" 
        OR "sewage$" OR "sludge"
        )
    )
  OR
    (
      ("recycl*" OR "re-cycl*"
      OR "refurbish" OR "re-furbish*" OR "remanufactur*" OR "re-manufactur*" OR "repurpos*" OR "re-purpos" 
      OR "cradle to cradle" OR "cradle-to-cradle"
      ) 
      NEAR/5 
        ("bioeconom*" OR "bio-econom*" OR "production" OR "produce$" OR "product$" OR "consumption" OR "consume$" OR "consumer$" OR "packaging" 
        OR "matter" OR "biomass" OR "resource$" OR "material$" 
        )
    )
  OR ("circular*" NEAR/5 ("econom*" OR "bioeconom*" OR "bio-econom*" OR "production" OR "produce$" OR "product$" OR "consumption" OR "consume$" OR "consumer$")) 
  OR 
    (
      ("utili*" OR "use" OR "using" OR "usage" OR "design" OR "designed" OR "designing") 
      NEAR/5 ("sidestream$" OR "side-stream$" OR "byproduct$" OR "by-product$")
    )   
  OR 
    (
      ("sustainab*" OR "environmental*" OR "ecological*" OR "eco" OR "green" OR "bioeconom*") 
      NEAR/15 
        ("recycl*" OR "re-cycl*" 
        OR 
          (
            ("lifecycle$" OR "life-cycle$" OR "cradle to cradle" OR "cradle-to-cradle" OR "footprint") 
            NEAR/5 
                ("material$" OR "product$" OR "production" OR "produce$" OR "service$" OR "consumption" OR "consume$" OR "consumer$" OR "packaging"
                OR "analys*" OR "assessment$" OR "assess" OR "assessed"
                )
          )
        )
    )
  OR "zero waste"
)
```


### Target 12.6

> **12.6 Encourage companies, especially large and transnational companies, to adopt sustainable practices and to integrate sustainability information into their reporting cycle**
> 
> 12.6.1 Number of companies publishing sustainability reports

This target is interpreted to cover research about a) companies/organisations and sustainable practices/production, and b) companies/organisations reporting their sustainability/environmental information. 

The phrases search for companies of all sizes, i.e. they are not focused to large ones even though the target emphasises them. Term `producers` is used as a synonym to companies/firms in order to broaden the search. It does, however, also bring some irrelevant results about e.g. ecological research. We also include `institutions` and `"organi?ation"`, even though these may not only apply to companies.

Reporting or publishing sustainability information in any form is considered relevant, as according to metadata for indicator 12.6.1 (<a id="UNstats2021">[UN Statistics division, 2021](#f3)</a>) https://unstats.un.org/sdgs/metadata/files/Metadata-12-06-01.pdf the reporting does not have to be a designated "sustainability report". 

The concept of economical sustainability is used broadly and in some cases we found it hard to interpret which papers about financial sustainability are relevant to target 12.6. 

#### Phrase 1

This phrase aims to find research about companies and sustainable practices, sustainable production patterns or measures. The elements of the phrase are *sustainable + practices/production + companies/producers*.

The practices are mentioned in the metadata for indicator 12.6.1 (<a id="UNstats2021">[UN Statistics division, 2021](#f3)</a>) https://unstats.un.org/sdgs/metadata/files/Metadata-12-06-01.pdf (e.g. `procurements` `sourcing`). 

Terms for sustainable production and its elements e.g. `sustainable buildings and construction` and `product lifecycle` were found from the UN DESA publication *The 10 Year Framework of Programmes on Sustainable Consumption and Production Patterns (10YFP)* (<a id="UNDESA2014">[UN DESA, 2014](#f2)</a>). Some concepts are from the UNEP publication *ABC to SCP* subtitled *Towards a 10-Year Framework of Programmes on Sustainable Consumption and Production* (<a id="ABC">[UNEP, 2010](#f1)</a>): `cleaner production` `sustainable transport` `eco-labelling and certification` `sustainable marketing` `design for sustainability` `ecodesign` `environmentally sound technologies`. 

```py 
TS=
(
  (
    (
        (
          ("sustainab*" OR "environmental*" OR "ecological*" OR "eco" OR "green") 
          NEAR/5 
              ("practice$" OR "procedure$" OR "custom$" OR "praxis" OR "method$" OR "methodology" OR "methodologies" 
              OR "policies" OR "policy" OR "strateg*" OR "standard$" OR "code$ of conduct" 
              OR "procurement$" OR "sourcing" OR "acquisition$" OR "purchas*" OR "investment$" 

              OR "production" OR "produce$" OR "process*" OR "product$" 
              OR "retail" OR "retailer$" OR "trade" OR "market*"
              OR "handling" OR "storage" OR "transport*" OR "distribution" OR "packaging" OR "supply chain$"

              OR "consumption" OR "consume$" 
              OR "efficien*"
              OR "Sustainable Building and Construction Initiative" OR "SBCI" 
              OR "certification" OR "certificate$" OR "label$" OR "labelling"
              )
        ) 
        OR "cleaner production"
        OR "ecolabelling" OR "ecolabel$" OR "eco-labelling" OR "eco-label$" OR "environmental label$" 
        OR 
          (
            ("footprint" OR "lifecycle$" OR "life-cycle$" OR "cradle to cradle" OR "cradle-to-cradle") 
            NEAR/3 ("product$" OR "service$" OR "material$" OR "analys*" OR "analy?e" OR "assessment$" OR "assess" OR "assessed")
          ) 
        OR "ecobuildin$" OR "eco-building*"
        OR "environmentally sound technologies" 
        OR (("design*" OR "technolog*" OR "housing" OR "building$" OR "construction$") NEAR/3 ("green" OR "eco" OR "sustainab*")) 
    )
  )
  AND 
    ("company" OR "companies" OR "organi?ation" OR "enterprise$" OR "firm$" OR "corporation$" OR "conglomerate$" OR "business" OR "businesses" OR "corporate"
    OR "producer$" OR "industry" OR "industries" OR "manufacturer$" OR "industrial sector$" OR "commercial sector$" OR "logistics sector$" OR "manufacturing sector$"
    OR "institutions"
    ) 
)

```


#### Phrase 2

This phrase aims to find research about companies reporting their sustainability information. The elements of the phrase are *sustainability/responsibility + reporting + companies/producers*.

```py 
TS=
(
  ("environmental information disclosure$" 
  OR
    (
      ("sustainab*" OR "responsib*" OR "environmental") 
      NEAR/5 
        ("report$" OR "reporting" OR "accounting" 
        OR (("publish*" OR "disclos*") NEAR/3 ("information" OR "data"))
        ) 
    )
  )
  NEAR/15 
      ("company" OR "companies" OR "organi?ation" OR "enterprise$" OR "firm$" OR "corporation$" OR "conglomerate$" OR "business" OR "businesses" OR "corporate"
      OR "producer$" OR "industry" OR "industries" OR "manufacturer$" OR "industrial sector$" OR "commercial sector$" OR "logistics sector$" OR "manufacturing sector$"
      OR "institution$"
      )
)
```


### Target 12.7

> **12.7 Promote public procurement practices that are sustainable, in accordance with national policies and priorities**
> 
> 12.7.1 Degree of sustainable public procurement policies and action plan implementation

This target is interpreted to cover research about sustainable public procurements.

Some of the terms used as variations of practices/policies are from UNEP *One planet SSP Index Calculation Methodology* (<a id="UNEPSPP">[UNEP, 2022](#f13)</a>). Terms `fair trade` `human rights` `employment of minorities` `Best value for Money` `Life-cycle costing`and `Most Economically Advantageous Tender` are mentioned as concepts of sustainable procurements in the metadata for indicator 12.7.1 (<a id="UNstats2021">[UN Statistics division, 2021](#f3)</a>) https://unstats.un.org/sdgs/metadata/files/Metadata-12-07-01.pdf. 

Terms `sustainable` and `investments` are used in many fields, and bring some irrelevant results about e.g. sustainable investements/procurements in health care. These have not been excluded as the exclusion of them would not be possible without losing many articles relevant to the topics of target 12.7.

The elements of the phrase are *sustainable + procurements + public/national*

```py 
TS=
(
      ("sustainable public procurement$" OR "circular public procurement$" OR "green public procurement$"
      OR
        (
          ("sustainab*" OR "socially responsible" OR "social responsibilit*" OR "environmental*" OR "ecological*" OR "eco" OR "green" OR "circular"
          OR "fair trade" OR "human rights"
          OR "Best value for Money" 
          OR "lifecycle$" OR "life-cycle$" 
          OR "employment of minorities" OR "employment of minority" 
          OR "Most Economically Advantageous Tender"
          )  
          NEAR/15  
            (
              ("procurement$" OR "acquisition$" OR "purchas*" OR "contract$" OR "tender$")      
              NEAR/5 ("national" OR "country" OR "countries" OR "domestic" OR "government*" OR "administrat*" OR "public" OR "local authorit*")
            )
        )
      )
)
```


### Target 12.8

> **12.8 By 2030, ensure that people everywhere have the relevant information and awareness for sustainable development and lifestyles in harmony with nature**
> 
> 12.8.1 Extent to which (i) global citizenship education and (ii) education for sustainable development are mainstreamed in (a) national education policies; (b) curricula; (c) teacher education; and (d) student assessment

This target is interpreted to cover research about education, awareness or information, with respect to sustainable development, sustainable consumption and production, or sustainable lifestyles. The indicator for this target is a shared indicator with **target 4.7** and **13.3**. However, the phrases for 12.8 are more focused on environmental sustainability to reflect the mentioning of "lifestyles in harmony with nature" in the target. By the definition in the UNEP publication *ABC of SDP* (<a id="ABC">[UNEP, 2010](#f1)</a>) "*Education for Sustainable Development (ESD) concerns all levels of education and all social contexts (family, school, workplace, community)*". For this reason, we do not restrict to only formal education.

In an earlier version we had also interpreted this to include research about behaviour and motivation, but on review have decided this is too indirect for the education and awareness focus of the target.

#### Phrase 1

The elements of the phrase are *education for sustainable development*.

The term `education` by itself brings many results which are irrelevant to this target, even when combined with sustainability (e.g. sustainability in higher education institutions). To remove these, "education" is used in phrases specific to education for sustainable development. 

```py 
TS= ("education for sustainab*" OR "education in sustainab*" OR "education on sustainab*" OR "sustainable development education" OR "sustainability education")
```

#### Phrase 2

The elements of the phrase are *education + sustainability/SCP + people/consumers/lifestyles*.

The term `education` by itself brings many results which are irrelevant to this target, even when combined with sustainability (e.g. sustainability in higher education institutions). To remove these `education` and most of the other *education terms* are combined with consumer/person groups. Still, terms for disseminating information/raising awareness/teaching/learning combined with sustainability/environmental/environment tend to bring irrelevant results about e.g. learning environment or health education. These are hard to exclude from the results without losing the core of relevant results - the `NOT` part aims to remove some of these (particularly medical works which may study "environmental factors"). Many of the *sustainability/SCP* terms are taken from 12.1, with some concepts from the UNEP publication *ABC to SCP* (<a id="ABC">[UNEP, 2010](#f1)</a>) are used as specifying terms: `eco-labelling` `product footprint` and `recycling`.

```py
TS=
(
  ("awareness" OR "lifelong learning" 
  OR
    (
      ("information" OR "knowledge" OR "aware" OR "guide$" OR "instruct*" OR "learn*" OR "educat*" OR "teach*")
      NEAR/15
          ("consumer$" OR "customer$" OR "resident$" OR "visitor$" OR "guest$" OR "tourist$" OR "employee$" OR "farmer$"
          OR "citizen$" OR "children" OR "teenager$" OR "adolescent$" OR "the elderly" OR "public" OR "student$" OR "adult$" OR "people" OR "women" OR "men"
          OR "purchas*" OR "buying" OR "habit$"
          OR (("responsib*" OR "sustainable" OR "green" OR "circular" OR "eco" OR "environmental*") NEAR/5 ("consumption" OR "life-style$" OR "lifestyle$"))
          )
    )
  )
  NEAR/5
      ("sustainability" OR "sustainable development" OR "environmental*" OR "ecological*" OR "eco" OR "green" OR "socially responsible" OR "social responsib*"
      OR (("responsib*" OR "sustainable" OR "circular") NEAR/3 ("tourism" OR "production" OR "consumption" OR "life-style$" OR "lifestyle$" OR "purchas*" OR "waste")) 
      OR (("circular*" OR "sustainab*") NEAR/5 ("econom*" OR "bioeconom*" OR "bio-econom*" OR "produce$" OR "product$" OR "consume$" OR "consumer$"))
      OR "cleaner production"
      OR "resource efficiency" OR "resource use efficiency" OR "material efficiency" OR "material use efficiency" OR "energy efficiency"
      OR "ecolabel*" OR "eco-label*" OR "environmental label$" 
      OR "ecobuilding$" OR "eco-building$" 
      OR "footprint$" OR "cradle to cradle" OR "cradle-to-cradle"
      OR "recycl*" OR "re-cycl*" OR "reuse$" OR "re-use$" OR "reusing" OR "re-using" 
      OR "refurbish*" OR "re-furbish*" OR "remanufactur*" OR "re-manufactur*" 
      OR "repurpos*" OR "re-purpos*" 
      OR "compost*"
      OR "renewable energy"
      )        
)
NOT TS=(("environmental factor$" OR "environmental constraint$") NOT ("awareness" OR "education"))
```

### Target 12.a

> **12.a Support developing countries to strengthen their scientific and technological capacity to move towards more sustainable patterns of consumption and production**
> 
> 12.a.1 Installed renewable energy-generating capacity in developing countries (in watts per capita)

This target is interpreted to cover research about the capacity of low- and middle-income countries for sustainable consumption and production. We consider this to include research about renewable energy in these countries, given the indicator.

Our classification of countries as least developed countries (LDCs), small island developing states (SIDS) and landlocked developing states (LDS) is taken from the Statistical Annex of United Nations World Economic Situation and Prospects (tables F, H and I) (<a id="UNLDCs">[United Nations, 2016, 2017, 2018, 2019, 2020, 2021](#f4)</a>). Additional terms for these countries, generic terms for country groups, and terms for low and middle income countries (LMICs) were gathered from the LMIC 2020 filter from the Norwegian Satellite of Cochrane Effective Practice and Organisation of Care (EPOC), developed by the Norwegian Institute of Public Heath (https://epoc.cochrane.org/lmic-filters).

#### Phrase 1

This phrase aims to find research about the capacity of developing countries regarding sustainable consumption and production. The elements of the phrase are *capacity + sustainable consumption & production + developing countries*.

The specific programme areas `consumer information` `sustainable lifestyles and education` `sustainable public procurement` `sustainable buildings and construction` `sustainable tourism` `sustainable food systems` and the definitions of them are from the UN DESA publication *The 10 Year Framework of Programmes on Sustainable Consumption and Production Patterns (10YFP)* (<a id="UNDESA2014">[UN DESA, 2014](#f2)</a>). The concepts `resource efficiency` and `product lifecycle` are also mentioned in the 10YFP. Some concepts, even though not mentioned in the 10YFP, are included from the UNEP publication *ABC to SCP*, subtitled *Towards a 10-Year Framework of Programmes on Sustainable Consumption and Production* (<a id="ABC">[UNEP, 2010](#f1)</a>): `waste management` `cleaner production` `sustainable transport` `eco-labelling and certification` `sustainable marketing` `design for sustainability` `ecodesign` `environmentally sound technologies`.

`lifestyle$` is combined in fixed phrases (e.g. `sustainable lifestyle$`) as a NEAR combination with e.g. "environmental" added irrelevant results from medicine (e.g. "environmental and lifestyle factors in this disease").


```py 
TS=
(
  ("institutional capacity" OR "human capacity" OR "technological capacity" OR "scientific capacity" OR "financial capacity" 
  OR "capacity building" OR "capacity development" OR "build* capacity" OR "develop* capacity" 
  OR "infrastructure$" OR "facilities" OR "tools" OR "technical support" OR "managerial support"
  OR "research" OR "knowledge" OR "skills" OR "competenc*" OR "expertise" OR "R&D" OR "innovation" 
  OR "communication" OR "social network$" OR "information network$" OR "campaign$" 
  OR "awareness" OR "disseminat*" OR "educat*" OR "training"
  OR "cooperation" OR "collaboration" OR "partnership$" 
  OR "knowledge transfer*" OR "transfer of technolog*" OR "technological transfer" OR "technology transfer"
  OR "expenditure" OR "invest" OR "investing" OR "investment$" OR "financing" OR "spending" OR "funding" OR "funder$" OR "fund$" OR "grant$"
  OR "financial support" OR "financial resources"
  OR "incentive$" OR "taxes" OR "tax" OR "fees" OR "subsidy" OR "subsidies" OR "subsidi?ing" OR "subsidi?e"
  OR "ODA" OR "cooperation fund$" OR "development spending" OR "development aid" OR "development assistance" OR "foreign aid" OR "international aid" OR "international assistance"
  OR "policy" OR "policies" OR "empower*" OR "strateg*" OR "programme$" OR "program$" OR "intervention$" 
  )
  NEAR/15 
    (
      (
        ("sustainab*" OR "environmental*" OR "ecological*" OR "eco" OR "green") 
        NEAR/15 
            ("production" OR "produce$" OR "process*" OR "product$" 
            OR "consumption" OR "consume$" OR "consumer$" 
            OR "retail" OR "retailer$" OR "trade" OR "market*"
            OR "handling" OR "storage" OR "transport*" OR "distribution" OR "packaging" OR "supply chain$" 
            OR "procurement$" OR "acquisition$" OR "purchas*" OR "investment$" 
            OR "resource efficiency" OR "resource use efficiency" OR "material efficiency" OR "material use efficiency" 
            OR ("energy efficien*" NEAR/5 ("housing" OR "building$" OR "construction$")) 
            OR "Sustainable Building and Construction Initiative" OR ("SBCI" NEAR/3 "UNEP") 
            OR "tourism" OR "tourist$" OR "travel*" OR "hospitality" OR "leisure"
            OR "food system$" OR "food production" OR "food consumption" OR "food security" 
            OR "agricultur*" OR "cropping system$" OR "agroforest*" OR "agro forest*" OR "aquaculture" OR "fisher*" OR "fish farm*" 
            OR 
              (
                ("lifecycle$" OR "life-cycle$" OR "cradle to cradle" OR "cradle-to-cradle" OR "footprint") 
                NEAR/5 ("material$" OR "service$" OR "analy?is" OR "analy?es" OR "analy?e" OR "assessment$" OR "assess" OR "assessed")
              ) 
            OR 
              (
                ("waste$" OR "biowaste$" OR "ewaste$" OR "e-waste$" OR "garbage" OR "trash" OR "trashes" OR "litter" OR "rubbish" OR "sewage$" OR "sludge") 
                NEAR/5 
                    ("management" OR "handling" OR "packaging" OR "labelling" OR "storing" OR "disposal" OR "dispose$" OR "incinerat*" OR "combust*" 
                    OR "collection" OR "collect$" OR "collected" OR "transport*" OR "treatment" OR "processing" OR "processed" OR "end of life" OR "end of chain" 
                    OR "sorting" OR "sort$" OR "sorted"
                    )
              ) 
            )
        ) 
        OR "ecobuilding$" OR "eco-building$"
        OR "ecotourism" OR "eco-tourism"
        OR ("responsib*" NEAR/3 ("tourist$" OR "tourism" OR "consumer$" OR "consumption")) 
        OR "cleaner production"
        OR "sustainable lifestyle$" OR "sustainable life style$" OR "green lifestyle$" OR "eco lifestyle$" OR "environmental lifestyle$"
        OR 
          (
            ("recycl*" OR "re-cycl*" OR "reuse$" OR "re-use$" OR "reusing" OR "re-using"  
            OR "refurbish*" OR "re-furbish*" OR "remanufactur*" OR "re-manufactur*" 
            OR "repurpos*" OR "re-purpos*" 
            OR "compost*" OR "codigest*" OR "co-digest*" 
            OR "resource efficiency" OR "resource use efficiency" OR "material efficiency" OR "material use efficiency"
            ) 
            NEAR/5 
              ("bioeconom*" OR "bio-econom*" OR "production" OR "produce$" OR "product$" OR "consumption" OR "consume$" OR "consumer$" OR "packaging" 
              OR "sidestream$" OR "side-stream$" OR "byproduct$" OR "by-product$" 
              OR "resource$" OR "material$" OR "matter" OR "biomass" 
              OR "waste$" OR "biowaste$" OR "ewaste$" OR "e-waste$" OR "garbage" OR "trash" OR "trashes" OR "litter" OR "rubbish" OR "sewage$" OR "sludge"
              )
          )
        OR ("circular*" NEAR/5 ("econom*" OR "bioeconom*" OR "production" OR "produce$" OR "product$" OR "consumption" OR "consume$" OR "consumer$")) 
        OR 
          (
            ("utili*" OR "use" OR "using" OR "usage" OR "design" OR "designed" OR "designing") 
            NEAR/5 ("sidestream$" OR "side-stream$" OR "byproduct$" OR "by-product$")
          ) 
        OR 
          (
            ("design*" OR "technolog*" OR "housing" OR "building$" OR "construction$") 
            NEAR/3 ("green" OR "eco" OR "sustainab*")
          ) 
        OR "ecolabelling" OR "ecolabel$" OR "eco-labelling" OR "eco-labels" OR "environmental label$" 
        OR 
          (
            ("certification" OR "certificate$" OR "label$" OR "labelling") 
            NEAR/5 ("sustainab*" OR "responsib*" OR "environmental*" OR "ecological*" OR "eco" OR "green")
          )
      )
) 

AND 
TS=("least developed countr*" OR "least developed nation$"
    OR "developing countr*" OR "developing nation$" OR "developing states" OR "developing world"
    OR "less developed countr*" OR "less developed nation$" OR "under developed countr*" OR "under developed nation$" OR "underdeveloped countr*" OR "underdeveloped nation$" OR "underserved countr*" OR "underserved nation$" OR "deprived countr*" OR "deprived nation$"
    OR "middle income countr*" OR "middle income nation$"
    OR "low income countr*" OR "low income nation$" OR "lower income countr*" OR "lower income nation$"
    OR "poor countr*" OR "poor nation$" OR "poorer countr*" OR "poorer nation$"
    OR "lmic" OR "lmics" OR "third world" OR "global south" OR "lami countr*" OR "transitional countr*" OR "emerging economies" OR "emerging nation$"
    OR  "Angola*" OR "Benin" OR "beninese" OR "Burkina Faso" OR "Burkina fasso" OR "burkinese" OR "burkinabe" OR "Burundi*" OR "Central African Republic" OR "Chad" OR "Comoros" OR "comoro islands" OR "iles comores" OR "Congo" OR "congolese" OR "Djibouti*" OR "Eritrea*" OR "Ethiopia*" OR "Gambia*" OR "Guinea" OR "Guinea-Bissau" OR "guinean" OR "Lesotho" OR "lesothan*" OR "Liberia*" OR "Madagasca*" OR "Malawi*" OR "Mali" OR "malian" OR "Mauritania*" OR "Mozambique" OR "mozambican$" OR "Niger" OR "Rwanda*" OR "Sao Tome and Principe" OR "Senegal*" OR "Sierra Leone*" OR "Somalia*" OR "South Sudan" OR "Sudan" OR "sudanese" OR "Togo" OR "togolese" OR "tongan" OR "Uganda*" OR "Tanzania*" OR "Zambia*" OR "Cambodia*" OR "Kiribati*" OR "Lao People’s democratic republic" OR "Laos" OR "Myanmar" OR "myanma" OR "Solomon islands" OR "Timor Leste" OR "Tuvalu*" OR "Vanuatu*" OR "Afghanistan" OR "afghan$" OR "Bangladesh*" OR "Bhutan*" OR "Nepal*" OR "Yemen*" OR "Haiti*"      OR  "Antigua and Barbuda" OR "Antigua & Barbuda" OR "antiguan$" OR "Bahamas" OR "Bahrain" OR "Barbados" OR "Belize" OR "Cabo Verde" OR "Cape Verde" OR "Comoros" OR "comoro islands" OR "iles comores" OR "Cuba" OR "cuban$" OR "Dominica*" OR "Dominican Republic" OR "Micronesia*" OR "Fiji" OR "fijian$" OR "Grenada*" OR "Guinea-Bissau" OR "Guyana*" OR "Haiti*" OR "Jamaica*" OR "Kiribati*" OR "Maldives" OR "maldivian$" OR "Marshall Islands" OR "Mauritius" OR "mauritian$" OR "Nauru*" OR "Palau*" OR "Papua New Guinea*" OR "Saint Kitts and Nevis" OR "st kitts and nevis" OR "Saint Lucia*" OR "St Lucia*" OR "Vincent and the Grenadines" OR "Vincent & the Grenadines" OR "Samoa*" OR "Sao Tome" OR "Seychelles" OR "seychellois*" OR "Singapore*" OR "Solomon Islands" OR "Surinam*" OR "Timor-Leste" OR "timorese" OR "Tonga*" OR "Trinidad and Tobago" OR "Trinidad & Tobago" OR "trinidadian$" OR "tobagonian$" OR "Tuvalu*" OR "Vanuatu*" OR "Anguilla*" OR "Aruba*" OR "Bermuda*" OR "Cayman Islands" OR "Northern Mariana$" OR "Cook Islands" OR "Curacao" OR "French Polynesia*" OR "Guadeloupe*" OR "Guam" OR "Martinique" OR "Montserrat" OR "New Caledonia*" OR "Niue" OR "Puerto Rico" OR "puerto rican" OR "Sint Maarten" OR "Turks and Caicos" OR "Turks & Caicos" OR "Virgin Islands"      OR  "Afghanistan" OR "afghan*" OR "Armenia*" OR "Azerbaijan*" OR "Bhutan" OR "bhutanese" OR "Bolivia*" OR "Botswana*" OR "Burkina Faso" OR "Burundi" OR "Central African Republic" OR "Chad" OR "Eswatini" OR "eswantian" OR "Ethiopia*" OR "Kazakhstan*" OR "kazakh" OR "Kyrgyzstan" OR "Kyrgyz*" OR "kirghizia" OR "kirgizstan" OR "Lao People’s Democratic Republic" OR "Laos" OR "Lesotho" OR "Malawi" OR "malawian" OR "Mali" OR "Mongolia*" OR "Nepal*" OR "Niger" OR "North Macedonia" OR "Republic of Macedonia" OR "Paraguay" OR "Moldova*" OR "Rwanda$" OR "South Sudan" OR "sudanese" OR "Swaziland" OR "Tajikistan" OR "tadjikistan" OR "tajikistani$" OR "Turkmenistan" OR "Uganda*" OR "Uzbekistan" OR "uzbekistani$" OR "Zambia" OR "zambian$" OR "Zimbabwe*"      OR   "albania*" OR "algeria*" OR "angola*" OR "argentina*" OR "azerbaijan*" OR "bahrain*" OR "belarus*" OR "byelarus*" OR "belorussia" OR "belize*" OR "honduras" OR "honduran" OR "dahomey" OR "bosnia*" OR "herzegovina*" OR "botswana*" OR "bechuanaland" OR "brazil*" OR "brasil*" OR "bulgaria*" OR "upper volta" OR "kampuchea" OR "khmer republic" OR "cameroon*" OR "cameroun" OR "ubangi shari" OR "chile*" OR "china" OR "chinese" OR "colombia*" OR "costa rica*" OR "cote d’ivoire" OR "cote divoire" OR "cote d ivoire" OR "ivory coast" OR "croatia*" OR "cyprus" OR "cypriot" OR "czech" OR "ecuador*" OR "egypt*" OR "united arab republic" OR "el salvador*" OR "estonia*" OR "eswatini" OR "swaziland" OR "swazi" OR "gabon" OR "gabonese" OR "gabonaise" OR "gambia*" OR "ghana*" OR "gibralta*" OR "greece" OR "greek" OR "honduras" OR "honduran$" OR "hungary" OR "hungarian$" OR "india" OR "indian$" OR "indonesia*" OR "iran" OR "iranian$" OR "iraq" OR "iraqi$" OR "isle of man" OR "jordan" OR "jordanian$" OR "kenya*" OR "korea*" OR "kosovo" OR "kosovan$" OR "latvia*" OR "lebanon" OR "lebanese" OR "libya*" OR "lithuania*" OR "macau" OR "macao" OR "macanese" OR "malagasy" OR "malaysia*" OR "malay federation" OR "malaya federation" OR "malta" OR "maltese" OR "mauritania" OR "mauritanian$" OR "mexico" OR "mexican$" OR "montenegr*" OR "morocco" OR "moroccan$" OR "namibia*" OR "netherlands antilles" OR "nicaragua*" OR "nigeria*" OR "oman" OR "omani$" OR "muscat" OR "pakistan*" OR "panama*" OR "papua new guinea*" OR "peru" OR "peruvian$" OR "philippine$" OR "philipine$" OR "phillipine$" OR "phillippine$" OR "filipino$" OR "filipina$" OR "poland" OR "polish" OR "portugal" OR "portugese" OR "romania*" OR "russia" OR "russian$" OR "polynesia*" OR "saudi arabia*" OR "serbia*" OR "slovakia*" OR "slovak republic" OR "slovenia*" OR "melanesia*" OR "south africa*" OR "sri lanka*" OR "dutch guiana" OR "netherlands guiana" OR "syria" OR "syrian$" OR "thailand" OR "thai" OR "tunisia*" OR "ukraine" OR "ukrainian$" OR "uruguay*" OR "venezuela*" OR "vietnam*" OR "west bank" OR "gaza" OR "palestine" OR "palestinian$" OR "yugoslavia*" OR "turkish"  OR "turkey" OR "georgia"
    )
```

#### Phrase 2

This phrase aims to find research about the capacity of developing countries for renewable energy. The elements of the phrase are *capacity + renewable energy + developing countries*. 

Most of the renewable energy sources specified are mentioned in the metadata for indicator 12.a.1 (<a id="UNstats2021">[UN Statistics division, 2021](#f3)</a>) https://unstats.un.org/sdgs/metadata/files/Metadata-12-0a-01.pdf. 

```py
TS=
(
  ("institutional capacity" OR "human capacity" OR "technological capacity" OR "scientific capacity" OR "financial capacity" 
  OR "capacity building" OR "capacity development" OR "build* capacity" OR "develop* capacity" 
  OR "infrastructure$" OR "facilities" OR "tools" OR "technical support" OR "managerial support"
  OR "research" OR "knowledge" OR "skills" OR "competenc*" OR "expertise" OR "R&D" OR "innovation" 
  OR "communication" OR "social network$" OR "information network$" OR "campaign$" 
  OR "awareness" OR "disseminat*" OR "educat*" OR "training"
  OR "cooperation" OR "collaboration" OR "partnership$" 
  OR "knowledge transfer*" OR "transfer of technolog*" OR "technological transfer" OR "technology transfer"
  OR "expenditure" OR "invest" OR "investing" OR "investment$" OR "financing" OR "spending" OR "funding" OR "funder$" OR "fund$" OR "grant$"
  OR "financial support" OR "financial resources"
  OR "incentive$" OR "taxes" OR "tax" OR "fees" OR "subsidy" OR "subsidies" OR "subsidi?ing" OR "subsidi?e"
  OR "ODA" OR "cooperation fund$" OR "development spending" OR "development aid" OR "development assistance" OR "foreign aid" OR "international aid" OR "international assistance"
  OR "policy" OR "policies" OR "empower*" OR "strateg*" OR "programme$" OR "program$" OR "intervention$" 
  ) 
  AND         
      ("energy transition" 
      OR "geothermal heat pump$" OR "ground source heat pump$" 
      OR "solar PV" OR "photovoltaic$" OR "solar cell$" OR "solar panel$" OR "solar array" OR "solar energy collector$" OR "solar farm$" OR "solar plant$" OR "solar park$" 
      OR "solar district heating" OR "solar district cooling" OR "solar air heating system$" OR "solar space heating system$" 
      OR "wind farm$" OR "wind turbine$" OR "wind park$" OR "wind factory" OR "wind factories" 
      OR "hydropower*" OR "hydroelectric" OR "hydro-electric" OR "tidal turbine$" OR "stream turbine$" OR "current turbine$" OR "tidal power" OR "tidal energy" OR "marine energy" OR "wave energy"
      OR
        ( 
          ("power" OR "electricity" OR "energy") 
          NEAR/5
              ("clean" OR "sustainable" OR "renewable$" 
              OR "solar" OR "wind" 
              OR "geothermal" OR "hydrothermal" 
              OR "hydrokinetic" OR "marine" OR "tidal" OR "ocean energy" 
              OR "bioenergy" OR "biofuel$" OR "biodiesel"
              )
        ) 
      )
) 
AND 
TS=("least developed countr*" OR "least developed nation$"
    OR "developing countr*" OR "developing nation$" OR "developing states" OR "developing world"
    OR "less developed countr*" OR "less developed nation$" OR "under developed countr*" OR "under developed nation$" OR "underdeveloped countr*" OR "underdeveloped nation$" OR "underserved countr*" OR "underserved nation$" OR "deprived countr*" OR "deprived nation$"
    OR "middle income countr*" OR "middle income nation$"
    OR "low income countr*" OR "low income nation$" OR "lower income countr*" OR "lower income nation$"
    OR "poor countr*" OR "poor nation$" OR "poorer countr*" OR "poorer nation$"
    OR "lmic" OR "lmics" OR "third world" OR "global south" OR "lami countr*" OR "transitional countr*" OR "emerging economies" OR "emerging nation$"
    OR  "Angola*" OR "Benin" OR "beninese" OR "Burkina Faso" OR "Burkina fasso" OR "burkinese" OR "burkinabe" OR "Burundi*" OR "Central African Republic" OR "Chad" OR "Comoros" OR "comoro islands" OR "iles comores" OR "Congo" OR "congolese" OR "Djibouti*" OR "Eritrea*" OR "Ethiopia*" OR "Gambia*" OR "Guinea" OR "Guinea-Bissau" OR "guinean" OR "Lesotho" OR "lesothan*" OR "Liberia*" OR "Madagasca*" OR "Malawi*" OR "Mali" OR "malian" OR "Mauritania*" OR "Mozambique" OR "mozambican$" OR "Niger" OR "Rwanda*" OR "Sao Tome and Principe" OR "Senegal*" OR "Sierra Leone*" OR "Somalia*" OR "South Sudan" OR "Sudan" OR "sudanese" OR "Togo" OR "togolese" OR "tongan" OR "Uganda*" OR "Tanzania*" OR "Zambia*" OR "Cambodia*" OR "Kiribati*" OR "Lao People’s democratic republic" OR "Laos" OR "Myanmar" OR "myanma" OR "Solomon islands" OR "Timor Leste" OR "Tuvalu*" OR "Vanuatu*" OR "Afghanistan" OR "afghan$" OR "Bangladesh*" OR "Bhutan*" OR "Nepal*" OR "Yemen*" OR "Haiti*"      OR  "Antigua and Barbuda" OR "Antigua & Barbuda" OR "antiguan$" OR "Bahamas" OR "Bahrain" OR "Barbados" OR "Belize" OR "Cabo Verde" OR "Cape Verde" OR "Comoros" OR "comoro islands" OR "iles comores" OR "Cuba" OR "cuban$" OR "Dominica*" OR "Dominican Republic" OR "Micronesia*" OR "Fiji" OR "fijian$" OR "Grenada*" OR "Guinea-Bissau" OR "Guyana*" OR "Haiti*" OR "Jamaica*" OR "Kiribati*" OR "Maldives" OR "maldivian$" OR "Marshall Islands" OR "Mauritius" OR "mauritian$" OR "Nauru*" OR "Palau*" OR "Papua New Guinea*" OR "Saint Kitts and Nevis" OR "st kitts and nevis" OR "Saint Lucia*" OR "St Lucia*" OR "Vincent and the Grenadines" OR "Vincent & the Grenadines" OR "Samoa*" OR "Sao Tome" OR "Seychelles" OR "seychellois*" OR "Singapore*" OR "Solomon Islands" OR "Surinam*" OR "Timor-Leste" OR "timorese" OR "Tonga*" OR "Trinidad and Tobago" OR "Trinidad & Tobago" OR "trinidadian$" OR "tobagonian$" OR "Tuvalu*" OR "Vanuatu*" OR "Anguilla*" OR "Aruba*" OR "Bermuda*" OR "Cayman Islands" OR "Northern Mariana$" OR "Cook Islands" OR "Curacao" OR "French Polynesia*" OR "Guadeloupe*" OR "Guam" OR "Martinique" OR "Montserrat" OR "New Caledonia*" OR "Niue" OR "Puerto Rico" OR "puerto rican" OR "Sint Maarten" OR "Turks and Caicos" OR "Turks & Caicos" OR "Virgin Islands"      OR  "Afghanistan" OR "afghan*" OR "Armenia*" OR "Azerbaijan*" OR "Bhutan" OR "bhutanese" OR "Bolivia*" OR "Botswana*" OR "Burkina Faso" OR "Burundi" OR "Central African Republic" OR "Chad" OR "Eswatini" OR "eswantian" OR "Ethiopia*" OR "Kazakhstan*" OR "kazakh" OR "Kyrgyzstan" OR "Kyrgyz*" OR "kirghizia" OR "kirgizstan" OR "Lao People’s Democratic Republic" OR "Laos" OR "Lesotho" OR "Malawi" OR "malawian" OR "Mali" OR "Mongolia*" OR "Nepal*" OR "Niger" OR "North Macedonia" OR "Republic of Macedonia" OR "Paraguay" OR "Moldova*" OR "Rwanda$" OR "South Sudan" OR "sudanese" OR "Swaziland" OR "Tajikistan" OR "tadjikistan" OR "tajikistani$" OR "Turkmenistan" OR "Uganda*" OR "Uzbekistan" OR "uzbekistani$" OR "Zambia" OR "zambian$" OR "Zimbabwe*"      OR   "albania*" OR "algeria*" OR "angola*" OR "argentina*" OR "azerbaijan*" OR "bahrain*" OR "belarus*" OR "byelarus*" OR "belorussia" OR "belize*" OR "honduras" OR "honduran" OR "dahomey" OR "bosnia*" OR "herzegovina*" OR "botswana*" OR "bechuanaland" OR "brazil*" OR "brasil*" OR "bulgaria*" OR "upper volta" OR "kampuchea" OR "khmer republic" OR "cameroon*" OR "cameroun" OR "ubangi shari" OR "chile*" OR "china" OR "chinese" OR "colombia*" OR "costa rica*" OR "cote d’ivoire" OR "cote divoire" OR "cote d ivoire" OR "ivory coast" OR "croatia*" OR "cyprus" OR "cypriot" OR "czech" OR "ecuador*" OR "egypt*" OR "united arab republic" OR "el salvador*" OR "estonia*" OR "eswatini" OR "swaziland" OR "swazi" OR "gabon" OR "gabonese" OR "gabonaise" OR "gambia*" OR "ghana*" OR "gibralta*" OR "greece" OR "greek" OR "honduras" OR "honduran$" OR "hungary" OR "hungarian$" OR "india" OR "indian$" OR "indonesia*" OR "iran" OR "iranian$" OR "iraq" OR "iraqi$" OR "isle of man" OR "jordan" OR "jordanian$" OR "kenya*" OR "korea*" OR "kosovo" OR "kosovan$" OR "latvia*" OR "lebanon" OR "lebanese" OR "libya*" OR "lithuania*" OR "macau" OR "macao" OR "macanese" OR "malagasy" OR "malaysia*" OR "malay federation" OR "malaya federation" OR "malta" OR "maltese" OR "mauritania" OR "mauritanian$" OR "mexico" OR "mexican$" OR "montenegr*" OR "morocco" OR "moroccan$" OR "namibia*" OR "netherlands antilles" OR "nicaragua*" OR "nigeria*" OR "oman" OR "omani$" OR "muscat" OR "pakistan*" OR "panama*" OR "papua new guinea*" OR "peru" OR "peruvian$" OR "philippine$" OR "philipine$" OR "phillipine$" OR "phillippine$" OR "filipino$" OR "filipina$" OR "poland" OR "polish" OR "portugal" OR "portugese" OR "romania*" OR "russia" OR "russian$" OR "polynesia*" OR "saudi arabia*" OR "serbia*" OR "slovakia*" OR "slovak republic" OR "slovenia*" OR "melanesia*" OR "south africa*" OR "sri lanka*" OR "dutch guiana" OR "netherlands guiana" OR "syria" OR "syrian$" OR "thailand" OR "thai" OR "tunisia*" OR "ukraine" OR "ukrainian$" OR "uruguay*" OR "venezuela*" OR "vietnam*" OR "west bank" OR "gaza" OR "palestine" OR "palestinian$" OR "yugoslavia*" OR "turkish"  OR "turkey" OR "georgia"
    )


```

### Target 12.b

> **12.b Develop and implement tools to monitor sustainable development impacts for sustainable tourism that creates jobs and promotes local culture and products**
> 
> 12.b.1 Implementation of standard accounting tools to monitor the economic and environmental aspects of tourism sustainability

This target is interpreted to cover research about monitoring sustainable tourism. Creating jobs and promoting local cultures and products via sustainable tourism should be covered by this, if connected to monitoring. The elements of the phrase are *monitoring/regulating/accounting + sustainable + tourism*.

The definition of sustainable tourism according to UNWTO *Sustainable Tourism for Development Guidebook* (<a id="UNWTO">[UNWTO, 2013](#f14)</a>) is:
> *“Tourism that takes full account of its current and future economic, social and environmental impacts, addressing the needs of visitors, the industry, the environment, and host communities”*. 

Some specifying terms were found from the UNWTO guidebook (<a id="UNWTO">[UNWTO, 2013](#f14)</a>). 

```py 
TS=
(
  ("monitor*" OR "reporting" OR "report$" OR "accounting" OR "control*" OR "measur*" OR "assess*" OR "evaluat*" OR "survey*") 
  NEAR/15 
      (
        ("sustainab*" OR "responsib*" OR "environmental*" OR "ecological*" OR "eco" OR "green") 
        NEAR/3 ("tourism" OR "tourist$" OR "hospitality" OR "leisure" OR "ecotourism" OR "eco-tourism" OR "air travel" OR "hotel$")
      )
)

```


### Target 12.c

> **12.c Rationalize inefficient fossil-fuel subsidies that encourage wasteful consumption by removing market distortions, in accordance with national circumstances, including by restructuring taxation and phasing out those harmful subsidies, where they exist, to reflect their environmental impacts, taking fully into account the specific needs and conditions of developing countries and minimizing the possible adverse impacts on their development in a manner that protects the poor and the affected communities**
> 
> 12.c.1 Amount of fossil-fuel subsidies (production and consumption) per unit of GDP

This target is interpreted to cover research about subsidies and fossil fuels, and about taxation and fossil fuels. Developing countries are not specified as this target is interpreted to address all countries. Because of the themes and terms, some works about e.g. subsidies for renewable energy or carbon taxes may be in the results, if the works compare these with or look at effects on fossil fuel use.

UNEP report *Measuring Fossil Fuel Subsidies in the Context of the Sustainable Development Goals* (<a id="UNEPfossil">[UNEP, 2019](#f16)</a>) is used for definitions of fossil fuels and subsidies. According to the UNEP report fossils fuels do not include nuclear fuel, renewable energy and biofuels. The report recommends including also non-energy uses of fossil fuels (e.g. use for production of plastic) in the scope of SDG (p. 14). For this reason the phrases are built to search for any use of fossil fuels. 

We do not specify either production or consumption of fossil fuels as both are mentioned in the metadata for indicator 12.c.1 (<a id="UNstats2021">[UN Statistics division, 2021](#f3)</a>) https://unstats.un.org/sdgs/metadata/files/Metadata-12-0c-01.pdf.

#### Phrase 1

This phrase aims to find research about subsidies and fossil fuels. The elements of the phrase are *subsidies + fossil fuels*.

Most of the terms for subsidies were found in the UNEP report *Measuring Fossil Fuel Subsidies in the Context of the Sustainable Development Goals* (<a id="UNEPfossil">[UNEP, 2019](#f16)</a>) table 6 p. 19 - and for fossil fuels from table 5 p. 13.

```py 
TS=
(
  ("subsidies" OR "subsidy" OR "fiscal incentive$" 
  OR "price support*" OR "underpricing" OR "underprice$" OR "under-pricing" OR "under-price$" 
  OR ("below market" NEAR/3 ("lending" OR "loan$")) 
  OR (("credit$" OR "loan$" OR "debt$") NEAR/3 ("support*" OR "guarantee$" OR "restructur*" OR "cancel*"))
  OR ("market$" NEAR/3 "distor*")
  OR ("government*" NEAR/3 ("spending" OR "fund*" OR "ownership" OR "payment$"))
  ) 
  NEAR/15 ("fossil fuel$" OR "fossil-fuel$" OR "coal" OR "oil" OR "natural gas" OR "peat" OR "diesel fuel" OR "gasoline" OR "kerosene" OR "petroleum" OR "conventional energy") 
)
```

#### Phrase 2

This phrase aims to find research about taxation and fossil fuels. The elements of the phrase are *taxation + fossil fuels*.

```py
TS=
( 
  ("taxation" OR "taxes" OR "tax" OR "taxed" OR "tariff$" OR "duty" OR "fees" OR "fee") 
  NEAR/15 ("fossil fuel$" OR "fossil-fuel$" OR "coal" OR "oil" OR "natural gas" OR "peat" OR "diesel fuel" OR "gasoline" OR "kerosene" OR "petroleum" OR "conventional energy")   
)
NOT TS=("heavy duty" OR "light duty" OR "medium duty")

```

### Works mentioning the SDG

This phrase finds research which mentions this SDG. We include this as we consider works mentioning the SDG as relevant, and want to ensure they are found. It includes terms for the goal, and excludes specialist terms that may use the `SDG` acronym. Here we include both "sustainable consumption" as well as the actual short title "responsible consumption" as it seems these are often used interchangably. 

```py
TS=
("SDG 12" OR "SDGs 12" OR "SDG12" OR "sustainable development goal$ 12"
OR 
  (
    ("sustainable development goal$" OR "SDG$" OR "goal 12")
    NEAR/50 ("sustainable consumption" OR "responsible consumption")
  )
)
NOT 
  TS=("secoisolariciresinol diglycoside"
  OR "secoisolariciresinol diglucoside"
  OR "SD-stearic acid"
  OR "SD-HPMC"
  OR "short-duration grazing (SDG)"
  OR "short-duration group (SDG)"
  OR "set domain group (SDG)"
  OR "spleen-derived growth factor (SDG)"
  OR "steel design guide series (SDG)"
  OR "steel design guide (SDG)"
  OR "spray-dried gelatin (SDG)"
  OR "single-display groupware (SDG)"
  )
```


## 4. Contributions

* First draft (v. 1.1.0): Leena Byholm (Jan 2023)

* Internal review: Internal review currently only carried out on action approach.

* Second draft (v. 1.1.0): Leena Byholm (Jan 2023)

* Testing v1.2.2: Project group & Leena Byholm; see documentation https://doi.org/10.5281/zenodo.8386611

* v2.0.0: Caroline S. Armitage (Aug-Sep 2023), minor review Eli Heldaas Seland.

Specialist input: Terhi Latvala (D.Sc. Agricultural Economics), v1.1.0


## 5. Footnotes

<a id="f1"></a> UNEP (2010). *ABC of SCP Clarifying concepts on Sustainable Consumption and Production*. https://sustainabledevelopment.un.org/content/documents/945ABC_ENGLISH.pdf. [↩](#ABC)

<a id="f2"></a> UNDESA (2014). *The 10 Year Framework of Programmes on Sustainable Consumption and Production Patterns (10YFP)*. https://sdgs.un.org/sites/default/files/publications/1444HLPF_10YFP2.pdf. [↩](#UNDESA2014)

<a id="f3"></a> UN Statistics Division (2021). *SDG Indicators Metadata Repository*. https://unstats.un.org/sdgs/metadata [↩](#UNstats2021)

<a id="f4"></a> United Nations. (2016, 2017, 2018, 2019, 2020, 2021). *World Economic Situation and Prospects; Statistical Annex*. https://www.un.org/development/desa/dpad/document_gem/global-economic-monitoring-unit/world-economic-situation-and-prospects-wesp-report/ [↩](#UNLDCs)

<a id="f6"></a> UNEP (n.d.a). *ExpoloreTopics: Resource efficiency*. United Nations. https://www.unep.org/explore-topics/resource-efficiency/why-does-resource-efficiency-matter (Accessed 11 Oct. 2022). [↩](#UNEPRes)

<a id="f7"></a> UN DESA/DSDG et al. (2018). *2018 HLPF Review of SDGs implementation: SDG 12 - Ensure sustainable consumption and production patterns*. United Nations, Expert Group Meeting on Sustainable Development Goal 12: Progress and Prospects, New York. https://sustainabledevelopment.un.org/content/documents/196532018backgroundnotesSDG12.pdf [↩](#HLPF2018)

<a id="f8"></a> UN One Planet Network (n.d.a). *One Planet Network*. United Nations. https://www.oneplanetnetwork.org/ (Accessed 12 Oct. 2022). [↩](#UNone)

<a id="f9"></a> FAO (n.d.a). *SAVE FOOD: Global Initiative on Food Loss and Waste Reduction*. FAO. https://www.fao.org/save-food/background/en/ (Accessed 14 Oct. 2022). [↩](#FAO)

<a id="f10"></a> UN DESA (n.d.a). *Topics: Chemicals and waste*. United Nations. https://sdgs.un.org/topics/chemicals-and-waste (Accessed 17 Oct. 2022). [↩](#chemicals)

<a id="f11"></a> UNEP (2021). *Global Chemicals and Waste Indicator Review Document*. https://wedocs.unep.org/xmlui/bitstream/handle/20.500.11822/36753/GCWIR.pdf. [↩](#UNEPchemicals)

<a id="f12"></a> UNEP (n.d.). *Basel Convention on the Control of Transboundary Movements of Hazardous Wastes and Their Disposal, Annex VIII*. http://www.basel.int/Default.aspx?tabid=2387 (Accessed 18 Oct. 2022).  [↩](#UNEPBasel)

<a id="f13"></a> UNEP (2022). *SPP Index Calculation Methodology*. https://wedocs.unep.org/bitstream/handle/20.500.11822/37332/SPPICMG.pdf?sequence=3&isAllowed=y (Accessed 25 Oct. 2022).  [↩](#UNEPSPP)

<a id="f14"></a> UNWTO (2013). *Sustainable Tourism for Development Guidebook - Enhancing capacities for Sustainable Tourism for development in developing countries*. https://www.e-unwto.org/doi/epdf/10.18111/9789284415496. [↩](#UNWTO)

<a id="f15"></a> UN DESA (n.d.a). *Topics: Sustainable Tourism*. United Nations. https://sustainabledevelopment.un.org/topics/sustainabletourism (Accessed 3 Nov. 2022). [↩](#tourism)

<a id="f16"></a> UNEP (2019). *Measuring Fossil Fuel Subsidies in the Context of the Sustainable Development Goals*. https://wedocs.unep.org/bitstream/handle/20.500.11822/28111/FossilFuel.pdf?sequence=1&isAllowed=y [↩](#UNEPfossil)

<a id="f17"></a> UNEP (n.d.a). *Persistent Organic Pollutants (POPs) and Pesticides*. https://www.unep.org/cep/persistent-organic-pollutants-pops-and-pesticides [↩](#UNEPPOPs)

